grib2io.tables.section4_discipline0 API documentation

# grib2io.tables.section4_discipline0

View Source

       1table_4_2_0_0  = {
       2'0':['Temperature','K','TMP'],
       3'1':['Virtual Temperature','K','VTMP'],
       4'2':['Potential Temperature','K','POT'],
       5'3':['Pseudo-Adiabatic Potential Temperature (or Equivalent Potential Temperature)','K','EPOT'],
       6'4':['Maximum Temperature','K','TMAX'],
       7'5':['Minimum Temperature','K','TMIN'],
       8'6':['Dew Point Temperature','K','DPT'],
       9'7':['Dew Point Depression (or Deficit)','K','DEPR'],
      10'8':['Lapse Rate','K m-1','LAPR'],
      11'9':['Temperature Anomaly','K','TMPA'],
      12'10':['Latent Heat Net Flux','W m-2','LHTFL'],
      13'11':['Sensible Heat Net Flux','W m-2','SHTFL'],
      14'12':['Heat Index','K','HEATX'],
      15'13':['Wind Chill Factor','K','WCF'],
      16'14':['Minimum Dew Point Depression','K','MINDPD'],
      17'15':['Virtual Potential Temperature','K','VPTMP'],
      18'16':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
      19'17':['Skin Temperature','K','SKINT'],
      20'18':['Snow Temperature (top of snow)','K','SNOT'],
      21'19':['Turbulent Transfer Coefficient for Heat','Numeric','TTCHT'],
      22'20':['Turbulent Diffusion Coefficient for Heat','m2s-1','TDCHT'],
      23'21':['Apparent Temperature','K','APTMP'],
      24'22':['Temperature Tendency due to Shortwave Radiation','K s-1','TTSWR'],
      25'23':['Temperature Tendency due to Longwave Radiation','K s-1','TTLWR'],
      26'24':['Temperature Tendency due to Shortwave Radiation, Clear Sky','K s-1','TTSWRCS'],
      27'25':['Temperature Tendency due to Longwave Radiation, Clear Sky','K s-1','TTLWRCS'],
      28'26':['Temperature Tendency due to parameterizations','K s-1','TTPARM'],
      29'27':['Wet-Bulb Temperature','K','WETBT'],
      30'28':['Unbalanced Component of Temperature','K','UCTMP'],
      31'29':['Temperature Advection','K s-1','TMPADV'],
      32'30':['Latent Heat Net Flux Due to Evaporation','W m-2','LHFLXE'],
      33'31':['Latent Heat Net Flux Due to Sublimation','W m-2','LHFLXS'],
      34'32':['Wet-Bulb Potential Temperature','K','WETBPT'],
      35'33-191':['Reserved','unknown','unknown'],
      36'192-254':['Reserved for Local Use','unknown','unknown'],
      37'192':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
      38'193':['Temperature Tendency by All Radiation','K s-1','TTRAD'],
      39'194':['Relative Error Variance','unknown','REV'],
      40'195':['Large Scale Condensate Heating Rate','K s-1','LRGHR'],
      41'196':['Deep Convective Heating Rate','K s-1','CNVHR'],
      42'197':['Total Downward Heat Flux at Surface','W m-2','THFLX'],
      43'198':['Temperature Tendency by All Physics','K s-1','TTDIA'],
      44'199':['Temperature Tendency by Non-Radiation Physics','K s-1','TTPHY'],
      45'200':['Standard Dev. of IR Temp. over 1x1 deg. area','K','TSD1D'],
      46'201':['Shallow Convective Heating Rate','K s-1','SHAHR'],
      47'202':['Vertical Diffusion Heating rate','K s-1','VDFHR'],
      48'203':['Potential Temperature at Top of Viscous Sublayer','K','THZ0'],
      49'204':['Tropical Cyclone Heat Potential','J m-2 K','TCHP'],
      50'205':['Effective Layer (EL) Temperature','C','ELMELT'],
      51'206':['Wet Bulb Globe Temperature','K','WETGLBT'],
      52'255':['Missing','unknown','unknown'],
      53}
      54table_4_2_0_1  = {
      55'0':['Specific Humidity','kg kg-1','SPFH'],
      56'1':['Relative Humidity','%','RH'],
      57'2':['Humidity Mixing Ratio','kg kg-1','MIXR'],
      58'3':['Precipitable Water','kg m-2','PWAT'],
      59'4':['Vapor Pressure','Pa','VAPP'],
      60'5':['Saturation Deficit','Pa','SATD'],
      61'6':['Evaporation','kg m-2','EVP'],
      62'7':['Precipitation Rate','kg m-2 s-1','PRATE'],
      63'8':['Total Precipitation','kg m-2','APCP'],
      64'9':['Large-Scale Precipitation (non-convective)','kg m-2','NCPCP'],
      65'10':['Convective Precipitation','kg m-2','ACPCP'],
      66'11':['Snow Depth','m','SNOD'],
      67'12':['Snowfall Rate Water Equivalent','kg m-2 s-1','SRWEQ'],
      68'13':['Water Equivalent of Accumulated Snow Depth','kg m-2','WEASD'],
      69'14':['Convective Snow','kg m-2','SNOC'],
      70'15':['Large-Scale Snow','kg m-2','SNOL'],
      71'16':['Snow Melt','kg m-2','SNOM'],
      72'17':['Snow Age','day','SNOAG'],
      73'18':['Absolute Humidity','kg m-3','ABSH'],
      74'19':['Precipitation Type','See Table 4.201','PTYPE'],
      75'20':['Integrated Liquid Water','kg m-2','ILIQW'],
      76'21':['Condensate','kg kg-1','TCOND'],
      77'22':['Cloud Mixing Ratio','kg kg-1','CLMR'],
      78'23':['Ice Water Mixing Ratio','kg kg-1','ICMR'],
      79'24':['Rain Mixing Ratio','kg kg-1','RWMR'],
      80'25':['Snow Mixing Ratio','kg kg-1','SNMR'],
      81'26':['Horizontal Moisture Convergence','kg kg-1 s-1','MCONV'],
      82'27':['Maximum Relative Humidity','%','MAXRH'],
      83'28':['Maximum Absolute Humidity','kg m-3','MAXAH'],
      84'29':['Total Snowfall','m','ASNOW'],
      85'30':['Precipitable Water Category','See Table 4.202','PWCAT'],
      86'31':['Hail','m','HAIL'],
      87'32':['Graupel','kg kg-1','GRLE'],
      88'33':['Categorical Rain','Code table 4.222','CRAIN'],
      89'34':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
      90'35':['Categorical Ice Pellets','Code table 4.222','CICEP'],
      91'36':['Categorical Snow','Code table 4.222','CSNOW'],
      92'37':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
      93'38':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIVER'],
      94'39':['Percent frozen precipitation','%','CPOFP'],
      95'40':['Potential Evaporation','kg m-2','PEVAP'],
      96'41':['Potential Evaporation Rate','W m-2','PEVPR'],
      97'42':['Snow Cover','%','SNOWC'],
      98'43':['Rain Fraction of Total Cloud Water','Proportion','FRAIN'],
      99'44':['Rime Factor','Numeric','RIME'],
     100'45':['Total Column Integrated Rain','kg m-2','TCOLR'],
     101'46':['Total Column Integrated Snow','kg m-2','TCOLS'],
     102'47':['Large Scale Water Precipitation (Non-Convective)','kg m-2','LSWP'],
     103'48':['Convective Water Precipitation','kg m-2','CWP'],
     104'49':['Total Water Precipitation','kg m-2','TWATP'],
     105'50':['Total Snow Precipitation','kg m-2','TSNOWP'],
     106'51':['Total Column Water (Vertically Integrated Total Water (Vapor + Cloud Water/Ice))','kg m-2','TCWAT'],
     107'52':['Total Precipitation Rate','kg m-2 s-1','TPRATE'],
     108'53':['Total Snowfall Rate Water Equivalent','kg m-2 s-1','TSRWE'],
     109'54':['Large Scale Precipitation Rate','kg m-2 s-1','LSPRATE'],
     110'55':['Convective Snowfall Rate Water Equivalent','kg m-2 s-1','CSRWE'],
     111'56':['Large Scale Snowfall Rate Water Equivalent','kg m-2 s-1','LSSRWE'],
     112'57':['Total Snowfall Rate','m s-1','TSRATE'],
     113'58':['Convective Snowfall Rate','m s-1','CSRATE'],
     114'59':['Large Scale Snowfall Rate','m s-1','LSSRATE'],
     115'60':['Snow Depth Water Equivalent','kg m-2','SDWE'],
     116'61':['Snow Density','kg m-3','SDEN'],
     117'62':['Snow Evaporation','kg m-2','SEVAP'],
     118'63':['Reserved','unknown','unknown'],
     119'64':['Total Column Integrated Water Vapor','kg m-2','TCIWV'],
     120'65':['Rain Precipitation Rate','kg m-2 s-1','RPRATE'],
     121'66':['Snow Precipitation Rate','kg m-2 s-1','SPRATE'],
     122'67':['Freezing Rain Precipitation Rate','kg m-2 s-1','FPRATE'],
     123'68':['Ice Pellets Precipitation Rate','kg m-2 s-1','IPRATE'],
     124'69':['Total Column Integrated Cloud Water','kg m-2','TCOLW'],
     125'70':['Total Column Integrated Cloud Ice','kg m-2','TCOLI'],
     126'71':['Hail Mixing Ratio','kg kg-1','HAILMXR'],
     127'72':['Total Column Integrated Hail','kg m-2','TCOLH'],
     128'73':['Hail Precipitation Rate','kg m-2 s-1','HAILPR'],
     129'74':['Total Column Integrated Graupel','kg m-2','TCOLG'],
     130'75':['Graupel (Snow Pellets) Precipitation Rate','kg m-2 s-1','GPRATE'],
     131'76':['Convective Rain Rate','kg m-2 s-1','CRRATE'],
     132'77':['Large-Scale Rain Rate','kg m-2 s-1','LSRRATE'],
     133'78':['Total Column Integrated Water (all components including precipitation)','kg m-2','TCOLWA'],
     134'79':['Evaporation Rate','kg m-2 s-1','EVARATE'],
     135'80':['Total Condensate','kg kg-1','TOTCON'],
     136'81':['Total Column Integrated Condensate','kg m-2','TCICON'],
     137'82':['Cloud Ice Mixing Ratio','kg kg-1','CIMIXR'],
     138'83':['Specific Cloud Liquid Water Content','kg kg-1','SCLLWC'],
     139'84':['Specific Cloud Ice Water Content','kg kg-1','SCLIWC'],
     140'85':['Specific Rain Water Content','kg kg-1','SRAINW'],
     141'86':['Specific Snow Water Content','kg kg-1','SSNOWW'],
     142'87':['Stratiform Precipitation Rate','kg m-2 s-1','STRPRATE'],
     143'88':['Categorical Convective Precipitation','Code table 4.222','CATCP'],
     144'89':['Reserved','unknown','unknown'],
     145'90':['Total Kinematic Moisture Flux','kg kg-1 m s-1','TKMFLX'],
     146'91':['U-Component (Zonal) Kinematic Moisture Flux','kg kg-1 m s-1','UKMFLX'],
     147'92':['V-Component (Meridional) Kinematic Moisture Flux','kg kg-1 m s-1','VKMFLX'],
     148'93':['Relative Humidity With Respect to Water','%','RHWATER'],
     149'94':['Relative Humidity With Respect to Ice','%','RHICE'],
     150'95':['Freezing or Frozen Precipitation Rate','kg m-2 s-1','FZPRATE'],
     151'96':['Mass Density of Rain','kg m-3','MASSDR'],
     152'97':['Mass Density of Snow','kg m-3','MASSDS'],
     153'98':['Mass Density of Graupel','kg m-3','MASSDG'],
     154'99':['Mass Density of Hail','kg m-3','MASSDH'],
     155'100':['Specific Number Concentration of Rain','kg-1','SPNCR'],
     156'101':['Specific Number Concentration of Snow','kg-1','SPNCS'],
     157'102':['Specific Number Concentration of Graupel','kg-1','SPNCG'],
     158'103':['Specific Number Concentration of Hail','kg-1','SPNCH'],
     159'104':['Number Density of Rain','m-3','NUMDR'],
     160'105':['Number Density of Snow','m-3','NUMDS'],
     161'106':['Number Density of Graupel','m-3','NUMDG'],
     162'107':['Number Density of Hail','m-3','NUMDH'],
     163'108':['Specific Humidity Tendency due to Parameterizations','kg kg-1 s-1','SHTPRM'],
     164'109':['Mass Density of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWHVA'],
     165'110':['Specific Mass of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWHMA'],
     166'111':['Mass Mixing Ratio of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWHDA'],
     167'112':['Mass Density of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWGVA'],
     168'113':['Specific Mass of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWGMA'],
     169'114':['Mass Mixing Ratio of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWGDA'],
     170'115':['Mass Density of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWSVA'],
     171'116':['Specific Mass of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWSMA'],
     172'117':['Mass Mixing Ratio of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWSDA'],
     173'118':['Unbalanced Component of Specific Humidity','kg kg-1','UNCSH'],
     174'119':['Unbalanced Component of Specific Cloud Liquid Water content','kg kg-1','UCSCLW'],
     175'120':['Unbalanced Component of Specific Cloud Ice Water content','kg kg-1','UCSCIW'],
     176'121':['Fraction of Snow Cover','Proportion','FSNOWC'],
     177'122':['Precipitation intensity index','See Table 4.247','PIIDX'],
     178'123':['Dominant precipitation type','See Table 4.201','DPTYPE'],
     179'124':['Presence of showers','See Table 4.222','PSHOW'],
     180'125':['Presence of blowing snow','See Table 4.222','PBSNOW'],
     181'126':['Presence of blizzard','See Table 4.222','PBLIZZ'],
     182'127':['Ice pellets (non-water equivalent) precipitation rate','m s-1','ICEP'],
     183'128':['Total solid precipitation rate','kg m-2 s-1','TSPRATE'],
     184'129':['Effective Radius of Cloud Water','m','EFRCWAT'],
     185'130':['Effective Radius of Rain','m','EFRRAIN'],
     186'131':['Effective Radius of Cloud Ice','m','EFRCICE'],
     187'132':['Effective Radius of Snow','m','EFRSNOW'],
     188'133':['Effective Radius of Graupel','m','EFRGRL'],
     189'134':['Effective Radius of Hail','m','EFRHAIL'],
     190'135':['Effective Radius of Subgrid Liquid Clouds','m','EFRSLC'],
     191'136':['Effective Radius of Subgrid Ice Clouds','m','EFRSICEC'],
     192'137':['Effective Aspect Ratio of Rain','unknown','EFARRAIN'],
     193'138':['Effective Aspect Ratio of Cloud Ice','unknown','EFARCICE'],
     194'139':['Effective Aspect Ratio of Snow','unknown','EFARSNOW'],
     195'140':['Effective Aspect Ratio of Graupel','unknown','EFARGRL'],
     196'141':['Effective Aspect Ratio of Hail','unknown','EFARHAIL'],
     197'142':['Effective Aspect Ratio of Subgrid Ice Clouds','unknown','EFARSIC'],
     198'143':['Potential evaporation rate','kg m-2 s-1','PERATE'],
     199'144':['Specific rain water content (convective)','kg kg-1','SRWATERC'],
     200'145':['Specific snow water content (convective)','kg kg-1','SSNOWWC'],
     201'146':['Cloud ice precipitation rate','kg m-2 s-1','CICEPR'],
     202'147':['Character of precipitation','See Table 4.249','CHPRECIP'],
     203'148':['Snow evaporation rate','kg m-2 s-1','SNOWERAT'],
     204'149':['Cloud water mixing ratio','kg kg-1','CWATERMR'],
     205'150':['Column integrated eastward water vapor mass flux','kg m-1s-1','CEWVMF'],
     206'151':['Column integrated northward water vapor mass flux','kg m-1s-1','CNWVMF'],
     207'152':['Column integrated eastward cloud liquid water mass flux','kg m-1s-1','CECLWMF'],
     208'153':['Column integrated northward cloud liquid water mass flux','kg m-1s-1','CNCLWMF'],
     209'154':['Column integrated eastward cloud ice mass flux','kg m-1s-1','CECIMF'],
     210'155':['Column integrated northward cloud ice mass flux','kg m-1s-1','CNCIMF'],
     211'156':['Column integrated eastward rain mass flux','kg m-1s-1','CERMF'],
     212'157':['Column integrated northward rain mass flux','kg m-1s-1','CNRMF'],
     213'158':['Column integrated eastward snow mass flux','kg m-1s-1','CEFMF'],
     214'159':['Column integrated northward snow mass flux','kg m-1s-1','CNSMF'],
     215'160':['Column integrated divergence of water vapor mass flux','kg m-1s-1','CDWFMF'],
     216'161':['Column integrated divergence of cloud liquid water mass flux','kg m-1s-1','CDCLWMF'],
     217'162':['Column integrated divergence of cloud ice mass flux','kg m-1s-1','CDCIMF'],
     218'163':['Column integrated divergence of rain mass flux','kg m-1s-1','CDRMF'],
     219'164':['Column integrated divergence of snow mass flux','kg m-1s-1','CDSMF'],
     220'165':['Column integrated divergence of total water mass flux','kg m-1s-1','CDTWMF'],
     221'166':['Column integrated water vapor flux','kg m-1s-1','CWVF'],
     222'167':['Total column supercooled liquid water','kg m-2','TCSLW'],
     223'168':['Saturation specific humidity with respect to water','kg m-3','SSPFHW'],
     224'169':['Total column integrated saturation specific humidity with respect to water','kg m-2','TCISSPFHW'],
     225'170':['Mean Mass Diameter of Hail (see Note 10)','m','MEANHAIL'],
     226'171':['Estimated Maximum Diameter of Hail','m','MAXHAIL'],
     227'172-191':['Reserved','unknown','unknown'],
     228'192-254':['Reserved for Local Use','unknown','unknown'],
     229'192':['Categorical Rain','Code table 4.222','CRAIN'],
     230'193':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
     231'194':['Categorical Ice Pellets','Code table 4.222','CICEP'],
     232'195':['Categorical Snow','Code table 4.222','CSNOW'],
     233'196':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
     234'197':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIV'],
     235'198':['Minimum Relative Humidity','%','MINRH'],
     236'199':['Potential Evaporation','kg m-2','PEVAP'],
     237'200':['Potential Evaporation Rate','W m-2','PEVPR'],
     238'201':['Snow Cover','%','SNOWC'],
     239'202':['Rain Fraction of Total Liquid Water','non-dim','FRAIN'],
     240'203':['Rime Factor','non-dim','RIME'],
     241'204':['Total Column Integrated Rain','kg m-2','TCOLR'],
     242'205':['Total Column Integrated Snow','kg m-2','TCOLS'],
     243'206':['Total Icing Potential Diagnostic','non-dim','TIPD'],
     244'207':['Number concentration for ice particles','non-dim','NCIP'],
     245'208':['Snow temperature','K','SNOT'],
     246'209':['Total column integrated supercooled liquid water','kg m-2','TCLSW'],
     247'210':['Total column integrated melting ice','kg m-2','TCOLM'],
     248'211':['Evaporation - Precipitation','cm/day','EMNP'],
     249'212':['Sublimation (evaporation from snow)','W m-2','SBSNO'],
     250'213':['Deep Convective Moistening Rate','kg kg-1 s-1','CNVMR'],
     251'214':['Shallow Convective Moistening Rate','kg kg-1 s-1','SHAMR'],
     252'215':['Vertical Diffusion Moistening Rate','kg kg-1 s-1','VDFMR'],
     253'216':['Condensation Pressure of Parcali Lifted From Indicate Surface','Pa','CONDP'],
     254'217':['Large-scale moistening rate','kg kg-1 s-1','LRGMR'],
     255'218':['Specific humidity at top of viscous sublayer','kg kg-1','QZ0'],
     256'219':['Maximum specific humidity at 2m','kg kg-1','QMAX'],
     257'220':['Minimum specific humidity at 2m','kg kg-1','QMIN'],
     258'221':['Liquid precipitation (Rainfall)','kg m-2','ARAIN'],
     259'222':['Snow temperature, depth average','K','SNOWT'],
     260'223':['Total precipitation (nearest grid point)','kg m-2','APCPN'],
     261'224':['Convective precipitation (nearest grid point)','kg m-2','ACPCPN'],
     262'225':['Freezing Rain','kg m-2','FRZR'],
     263'226':['Predominant Weather','Numeric','PWTHER'],
     264'227':['Frozen Rain','kg m-2','FROZR'],
     265'228':['Flat Ice Accumulation (FRAM)','kg m-2','FICEAC'],
     266'229':['Line Ice Accumulation (FRAM)','kg m-2','LICEAC'],
     267'230':['Sleet Accumulation','kg m-2','SLACC'],
     268'231':['Precipitation Potential Index','%','PPINDX'],
     269'232':['Probability Cloud Ice Present','%','PROBCIP'],
     270'233':['Snow Liquid Ratio','kg kg-1','SNOWLR'],
     271'234':['Precipitation Duration','hour','PCPDUR'],
     272'235':['Cloud Liquid Mixing Ratio','kg kg-1','CLLMR'],
     273'236':['Hail Accumulation','m','HAILAC'],
     274'237':['Total Column Integrated Precipitation','kg m-2','TCOLP'],
     275'238':['Hourly Maximum of 1-minute Average Precipitation Rate','kg m-2 s-1','PRATE1MIN'],
     276'239':['Hourly Maximum of 5-minute Average Precipitation Rate','kg m-2 s-1','PRATE5MIN'],
     277'240':['Hourly Maximum of 10-minute Average Precipitation Rate','kg m-2 s-1','PRATE10MIN'],
     278'241':['Total Snow','kg m-2','TSNOW'],
     279'242':['Relative Humidity with Respect to Precipitable Water','%','RHPW'],
     280'245':['Hourly Maximum of Column Vertical Integrated Graupel on Entire Atmosphere','kg m-2','MAXVIG'],
     281'255':['Missing','unknown','unknown'],
     282}
     283table_4_2_0_2  = {
     284'0':['Wind Direction (from which blowing)','°','WDIR'],
     285'1':['Wind Speed','m s-1','WIND'],
     286'2':['U-Component of Wind','m s-1','UGRD'],
     287'3':['V-Component of Wind','m s-1','VGRD'],
     288'4':['Stream Function','m2 s-1','STRM'],
     289'5':['Velocity Potential','m2 s-1','VPOT'],
     290'6':['Montgomery Stream Function','m2 s-2','MNTSF'],
     291'7':['σ Coordinate Vertical Velocity','s-1','SGCVV'],
     292'8':['Vertical Velocity (Pressure)','Pa s-1','VVEL'],
     293'9':['Vertical Velocity (Geometric)','m s-1','DZDT'],
     294'10':['Absolute Vorticity','s-1','ABSV'],
     295'11':['Absolute Divergence','s-1','ABSD'],
     296'12':['Relative Vorticity','s-1','RELV'],
     297'13':['Relative Divergence','s-1','RELD'],
     298'14':['Potential Vorticity','K m2 kg-1 s-1','PVORT'],
     299'15':['Vertical U-Component Shear','s-1','VUCSH'],
     300'16':['Vertical V-Component Shear','s-1','VVCSH'],
     301'17':['Momentum Flux, U-Component','N m-2','UFLX'],
     302'18':['Momentum Flux, V-Component','N m-2','VFLX'],
     303'19':['Wind Mixing Energy','J','WMIXE'],
     304'20':['Boundary Layer Dissipation','W m-2','BLYDP'],
     305'21':['Maximum Wind Speed','m s-1','MAXGUST'],
     306'22':['Wind Speed (Gust)','m s-1','GUST'],
     307'23':['U-Component of Wind (Gust)','m s-1','UGUST'],
     308'24':['V-Component of Wind (Gust)','m s-1','VGUST'],
     309'25':['Vertical Speed Shear','s-1','VWSH'],
     310'26':['Horizontal Momentum Flux','N m-2','MFLX'],
     311'27':['U-Component Storm Motion','m s-1','USTM'],
     312'28':['V-Component Storm Motion','m s-1','VSTM'],
     313'29':['Drag Coefficient','Numeric','CD'],
     314'30':['Frictional Velocity','m s-1','FRICV'],
     315'31':['Turbulent Diffusion Coefficient for Momentum','m2 s-1','TDCMOM'],
     316'32':['η Coordinate Vertical Velocity','s-1','ETACVV'],
     317'33':['Wind Fetch','m','WINDF'],
     318'34':['Normal Wind Component','m s-1','NWIND'],
     319'35':['Tangential Wind Component','m s-1','TWIND'],
     320'36':['Amplitude Function for Rossby Wave Envelope for Meridional Wind','m s-1','AFRWE'],
     321'37':['Northward Turbulent Surface Stress (see Notes 4 and 7)','N m-2 s','NTSS'],
     322'38':['Eastward Turbulent Surface Stress (see Notes 4 and 7)','N m-2 s','ETSS'],
     323'39':['Eastward Wind Tendency Due to Parameterizations','m s-2','EWTPARM'],
     324'40':['Northward Wind Tendency Due to Parameterizations','m s-2','NWTPARM'],
     325'41':['U-Component of Geostrophic Wind','m s-1','UGWIND'],
     326'42':['V-Component of Geostrophic Wind','m s-1','VGWIND'],
     327'43':['Geostrophic Wind Direction','°','GEOWD'],
     328'44':['Geostrophic Wind Speed','m s-1','GEOWS'],
     329'45':['Unbalanced Component of Divergence','s-1','UNDIV'],
     330'46':['Vorticity Advection','s-2','VORTADV'],
     331'47':['Surface roughness for heat','m','SFRHEAT'],
     332'48':['Surface roughness for moisture','m','SFRMOIST'],
     333'49':['Wind stress','N m-2','WINDSTR'],
     334'50':['Eastward wind stress','N m-2','EWINDSTR'],
     335'51':['Northward wind stress','N m-2','NWINDSTR'],
     336'52':['U-component of wind stress','N m-2','UWINDSTR'],
     337'53':['V-component of wind stress','N m-2','VWINDSTR'],
     338'54':['Natural logarithm of surface roughness length for heat','m','NLSRLH'],
     339'55':['Natural logarithm of surface roughness length for moisture','m','NLSRLM'],
     340'56':['U-component of neutral wind','m s-1','UNWIND'],
     341'57':['V-component of neutral wind','m s-1','VNWIND'],
     342'58':['Magnitude of turbulent surface stress','N m-2','TSFCSTR'],
     343'59':['Vertical divergence','s-1','VDIV'],
     344'60':['Drag thermal coefficient','Numeric','DTC'],
     345'61':['Drag evaporation coefficient','Numeric','DEC'],
     346'62':['Eastward turbulent surface stress','N m-2','EASTTSS'],
     347'63':['Northward turbulent surface stress','N m-2','NRTHTSS'],
     348'64':['Eastward turbulent surface stress due to orographic form drag','N m-2','EASTTSSOD'],
     349'65':['Northward turbulent surface stress due to orographic form drag','N m-2','NRTHTSSOD'],
     350'66':['Eastward turbulent surface stress due to surface roughness','N m-2','EASTTSSSR'],
     351'67':['Northward turbulent surface stress due to surface roughness','N m-2','NRTHTSSSR'],
     352'68':['Convective Gust','m s-1','CNVGUST'],
     353'69':['Turbulent Gust','m s-1','TURBGUST'],
     354'70-191':['Reserved','unknown','unknown'],
     355'192-254':['Reserved for Local Use','unknown','unknown'],
     356'192':['Vertical Speed Shear','s-1','VWSH'],
     357'193':['Horizontal Momentum Flux','N m-2','MFLX'],
     358'194':['U-Component Storm Motion','m s-1','USTM'],
     359'195':['V-Component Storm Motion','m s-1','VSTM'],
     360'196':['Drag Coefficient','non-dim','CD'],
     361'197':['Frictional Velocity','m s-1','FRICV'],
     362'198':['Latitude of U Wind Component of Velocity','deg','LAUV'],
     363'199':['Longitude of U Wind Component of Velocity','deg','LOUV'],
     364'200':['Latitude of V Wind Component of Velocity','deg','LAVV'],
     365'201':['Longitude of V Wind Component of Velocity','deg','LOVV'],
     366'202':['Latitude of Presure Point','deg','LAPP'],
     367'203':['Longitude of Presure Point','deg','LOPP'],
     368'204':['Vertical Eddy Diffusivity Heat Exchange','m2 s-1','VEDH'],
     369'205':['Covariance between Meridional and Zonal Components of the Wind','m2 s-2','COVMZ'],
     370'206':['Covariance between Temperature and Zonal Components of the Wind','K*m s-1','COVTZ'],
     371'207':['Covariance between Temperature and Meridional Components of the Wind','K*m s-1','COVTM'],
     372'208':['Vertical Diffusion Zonal Acceleration','m s-2','VDFUA'],
     373'209':['Vertical Diffusion Meridional Acceleration','m s-2','VDFVA'],
     374'210':['Gravity wave drag zonal acceleration','m s-2','GWDU'],
     375'211':['Gravity wave drag meridional acceleration','m s-2','GWDV'],
     376'212':['Convective zonal momentum mixing acceleration','m s-2','CNVU'],
     377'213':['Convective meridional momentum mixing acceleration','m s-2','CNVV'],
     378'214':['Tendency of vertical velocity','m s-2','WTEND'],
     379'215':['ω (Dp/Dt) divided by density','K','OMGALF'],
     380'216':['Convective Gravity wave drag zonal acceleration','m s-2','CNGWDU'],
     381'217':['Convective Gravity wave drag meridional acceleration','m s-2','CNGWDV'],
     382'218':['Velocity Point Model Surface','unknown','LMV'],
     383'219':['Potential Vorticity (Mass-Weighted)','1/s/m','PVMWW'],
     384'220':['Hourly Maximum of Upward Vertical Velocity','m s-1','MAXUVV'],
     385'221':['Hourly Maximum of Downward Vertical Velocity','m s-1','MAXDVV'],
     386'222':['U Component of Hourly Maximum 10m Wind Speed','m s-1','MAXUW'],
     387'223':['V Component of Hourly Maximum 10m Wind Speed','m s-1','MAXVW'],
     388'224':['Ventilation Rate','m2 s-1','VRATE'],
     389'225':['Transport Wind Speed','m s-1','TRWSPD'],
     390'226':['Transport Wind Direction','Deg','TRWDIR'],
     391'227':['Earliest Reasonable Arrival Time (10% exceedance)','s','TOA10'],
     392'228':['Most Likely Arrival Time (50% exceedance)','s','TOA50'],
     393'229':['Most Likely Departure Time (50% exceedance)','s','TOD50'],
     394'230':['Latest Reasonable Departure Time (90% exceedance)','s','TOD90'],
     395'231':['Tropical Wind Direction','°','TPWDIR'],
     396'232':['Tropical Wind Speed','m s-1','TPWSPD'],
     397'233':['Inflow Based (ESFC) to 50% EL Shear Magnitude','kt','ESHR'],
     398'234':['U Component Inflow Based to 50% EL Shear Vector','kt','UESH'],
     399'235':['V Component Inflow Based to 50% EL Shear Vector','kt','VESH'],
     400'236':['U Component Bunkers Effective Right Motion','kt','UEID'],
     401'237':['V Component Bunkers Effective Right Motion','kt','VEID'],
     402'255':['Missing','unknown','unknown'],
     403}
     404table_4_2_0_3  = {
     405'0':['Pressure','Pa','PRES'],
     406'1':['Pressure Reduced to MSL','Pa','PRMSL'],
     407'2':['Pressure Tendency','Pa s-1','PTEND'],
     408'3':['ICAO Standard Atmosphere Reference Height','m','ICAHT'],
     409'4':['Geopotential','m2 s-2','GP'],
     410'5':['Geopotential Height','gpm','HGT'],
     411'6':['Geometric Height','m','DIST'],
     412'7':['Standard Deviation of Height','m','HSTDV'],
     413'8':['Pressure Anomaly','Pa','PRESA'],
     414'9':['Geopotential Height Anomaly','gpm','GPA'],
     415'10':['Density','kg m-3','DEN'],
     416'11':['Altimeter Setting','Pa','ALTS'],
     417'12':['Thickness','m','THICK'],
     418'13':['Pressure Altitude','m','PRESALT'],
     419'14':['Density Altitude','m','DENALT'],
     420'15':['5-Wave Geopotential Height','gpm','5WAVH'],
     421'16':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
     422'17':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
     423'18':['Planetary Boundary Layer Height','m','HPBL'],
     424'19':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
     425'20':['Standard Deviation of Subgrid Scale Orography','m','SDSGSO'],
     426'21':['Angle of Subgrid Scale Orography','rad','AOSGSO'],
     427'22':['Slope of Subgrid Scale Orography','Numeric','SSGSO'],
     428'23':['Gravity Wave Dissipation','W m-2','GWD'],
     429'24':['Anisotropy of Subgrid Scale Orography','Numeric','ASGSO'],
     430'25':['Natural Logarithm of Pressure in Pa','Numeric','NLPRES'],
     431'26':['Exner Pressure','Numeric','EXPRES'],
     432'27':['Updraught Mass Flux','kg m-2 s-1','UMFLX'],
     433'28':['Downdraught Mass Flux','kg m-2 s-1','DMFLX'],
     434'29':['Updraught Detrainment Rate','kg m-3 s-1','UDRATE'],
     435'30':['Downdraught Detrainment Rate','kg m-3 s-1','DDRATE'],
     436'31':['Unbalanced Component of Logarithm of Surface Pressure','-','UCLSPRS'],
     437'32':['Saturation water vapour pressure','Pa','SWATERVP'],
     438'33':['Geometric altitude above mean sea level','m','GAMSL'],
     439'34':['Geometric height above ground level','m','GHAGRD'],
     440'35':['Column integrated divergence of total mass flux','kg m-2 s-1','CDTMF'],
     441'36':['Column integrated eastward total mass flux','kg m-2 s-1','CETMF'],
     442'37':['Column integrated northward total mass flux','kg m-2 s-1','CNTMF'],
     443'38':['Standard deviation of filtered subgrid orography','m','SDFSO'],
     444'39':['Column integrated mass of atmosphere','kg m-2 s-1','CMATMOS'],
     445'40':['Column integrated eastward geopotential flux','W m-1','CEGFLUX'],
     446'41':['Column integrated northward geopotential flux','W m-1','CNGFLUX'],
     447'42':['Column integrated divergence of water geopotential flux','W m-2','CDWGFLUX'],
     448'43':['Column integrated divergence of geopotential flux','W m-2','CDGFLUX'],
     449'44':['Height of zero-degree wet-bulb temperature','m','HWBT'],
     450'45':['Height of one-degree wet-bulb temperature','m','WOBT'],
     451'46':['Pressure departure from hydrostatic state','Pa','PRESDHS'],
     452'47-191':['Reserved','unknown','unknown'],
     453'192-254':['Reserved for Local Use','unknown','unknown'],
     454'192':['MSLP (Eta model reduction)','Pa','MSLET'],
     455'193':['5-Wave Geopotential Height','gpm','5WAVH'],
     456'194':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
     457'195':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
     458'196':['Planetary Boundary Layer Height','m','HPBL'],
     459'197':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
     460'198':['MSLP (MAPS System Reduction)','Pa','MSLMA'],
     461'199':['3-hr pressure tendency (Std. Atmos. Reduction)','Pa s-1','TSLSA'],
     462'200':['Pressure of level from which parcel was lifted','Pa','PLPL'],
     463'201':['X-Gradient of Log Pressure','m-1','LPSX'],
     464'202':['Y-Gradient of Log Pressure','m-1','LPSY'],
     465'203':['X-Gradient of Height','m-1','HGTX'],
     466'204':['Y-Gradient of Height','m-1','HGTY'],
     467'205':['Layer Thickness','m','LAYTH'],
     468'206':['Natural Log of Surface Pressure','ln (kPa)','NLGSP'],
     469'207':['Convective updraft mass flux','kg m-2 s-1','CNVUMF'],
     470'208':['Convective downdraft mass flux','kg m-2 s-1','CNVDMF'],
     471'209':['Convective detrainment mass flux','kg m-2 s-1','CNVDEMF'],
     472'210':['Mass Point Model Surface','unknown','LMH'],
     473'211':['Geopotential Height (nearest grid point)','gpm','HGTN'],
     474'212':['Pressure (nearest grid point)','Pa','PRESN'],
     475'213':['Orographic Convexity','unknown','ORCONV'],
     476'214':['Orographic Asymmetry, W Component','unknown','ORASW'],
     477'215':['Orographic Asymmetry, S Component','unknown','ORASS'],
     478'216':['Orographic Asymmetry, SW Component','unknown','ORASSW'],
     479'217':['Orographic Asymmetry, NW Component','unknown','ORASNW'],
     480'218':['Orographic Length Scale, W Component','unknown','ORLSW'],
     481'219':['Orographic Length Scale, S Component','unknown','ORLSS'],
     482'220':['Orographic Length Scale, SW Component','unknown','ORLSSW'],
     483'221':['Orographic Length Scale, NW Component','unknown','ORLSNW'],
     484'222':['Effective Surface Height','m','EFSH'],
     485'255':['Missing','unknown','unknown'],
     486}
     487table_4_2_0_4  = {
     488'0':['Net Shortwave Radiation Flux (Surface)','W m-2','NSWRS'],
     489'1':['Net Shortwave Radiation Flux (Top of Atmosphere)','W m-2','NSWRT'],
     490'2':['Shortwave Radiation Flux','W m-2','SWAVR'],
     491'3':['Global Radiation Flux','W m-2','GRAD'],
     492'4':['Brightness Temperature','K','BRTMP'],
     493'5':['Radiance (with respect to wavenumber)','W m-1 sr-1','LWRAD'],
     494'6':['Radiance (with respect to wavelength)','W m-3 sr-1','SWRAD'],
     495'7':['Downward Shortwave Radiation Flux','W m-2','DSWRF'],
     496'8':['Upward Shortwave Radiation Flux','W m-2','USWRF'],
     497'9':['Net Shortwave Radiation Flux','W m-2','NSWRF'],
     498'10':['Photosynthetically Active Radiation','W m-2','PHOTAR'],
     499'11':['Net Shortwave Radiation Flux, Clear Sky','W m-2','NSWRFCS'],
     500'12':['Downward UV Radiation','W m-2','DWUVR'],
     501'13':['Direct Shortwave Radiation Flux','W m-2','DSWRFLX'],
     502'14':['Diffuse Shortwave Radiation Flux','W m-2','DIFSWRF'],
     503'15':['Upward UV radiation emitted/reflected from the Earths surface','W m-2','UVVEARTH'],
     504'16-49':['Reserved','unknown','unknown'],
     505'50':['UV Index (Under Clear Sky)','Numeric','UVIUCS'],
     506'51':['UV Index','Numeric','UVI'],
     507'52':['Downward Shortwave Radiation Flux, Clear Sky','W m-2','DSWRFCS'],
     508'53':['Upward Shortwave Radiation Flux, Clear Sky','W m-2','USWRFCS'],
     509'54':['Direct normal shortwave radiation flux,','W m-2','DNSWRFLX'],
     510'55':['UV visible albedo for diffuse radiation','%','UVALBDIF'],
     511'56':['UV visible albedo for direct radiation','%','UVALBDIR'],
     512'57':['UV visible albedo for direct radiation, geometric component','%','UBALBDIRG'],
     513'58':['UV visible albedo for direct radiation, isotropic component','%','UVALBDIRI'],
     514'59':['UV visible albedo for direct radiation, volumetric component','%','UVBDIRV'],
     515'60':['Photosynthetically active radiation flux, clear sky','W m-2','PHOARFCS'],
     516'61':['Direct shortwave radiation flux, clear sky','W m-2','DSWRFLXCS'],
     517'62':['Direct Normal Shortwave Radiation Flux, Clear Sky','W m-2','DNSWRFLXCS'],
     518'63':['Diffuse Shortwave Radiation Flux, Clear Sky','W m-2','DFSWRFLXCS'],
     519'64-191':['Reserved','unknown','unknown'],
     520'192-254':['Reserved for Local Use','unknown','unknown'],
     521'192':['Downward Shortwave Radiation Flux','W m-2','DSWRF'],
     522'193':['Upward Shortwave Radiation Flux','W m-2','USWRF'],
     523'194':['UV-B Downward Solar Flux','W m-2','DUVB'],
     524'195':['Clear sky UV-B Downward Solar Flux','W m-2','CDUVB'],
     525'196':['Clear Sky Downward Solar Flux','W m-2','CSDSF'],
     526'197':['Solar Radiative Heating Rate','K s-1','SWHR'],
     527'198':['Clear Sky Upward Solar Flux','W m-2','CSUSF'],
     528'199':['Cloud Forcing Net Solar Flux','W m-2','CFNSF'],
     529'200':['Visible Beam Downward Solar Flux','W m-2','VBDSF'],
     530'201':['Visible Diffuse Downward Solar Flux','W m-2','VDDSF'],
     531'202':['Near IR Beam Downward Solar Flux','W m-2','NBDSF'],
     532'203':['Near IR Diffuse Downward Solar Flux','W m-2','NDDSF'],
     533'204':['Downward Total Radiation Flux','W m-2','DTRF'],
     534'205':['Upward Total Radiation Flux','W m-2','UTRF'],
     535'206':['Diffuse Shortwave Radiation Flux, Clear Sky','W m-2','DFSWRFLXCS'],
     536'255':['Missing','unknown','unknown'],
     537}
     538table_4_2_0_5  = {
     539'0':['Net Longwave Radiation Flux (Surface)','W m-2','NLWRS'],
     540'1':['Net Longwave Radiation Flux (Top of Atmosphere)','W m-2','NLWRT'],
     541'2':['Longwave Radiation Flux','W m-2','LWAVR'],
     542'3':['Downward Longwave Radiation Flux','W m-2','DLWRF'],
     543'4':['Upward Longwave Radiation Flux','W m-2','ULWRF'],
     544'5':['Net Longwave Radiation Flux','W m-2','NLWRF'],
     545'6':['Net Longwave Radiation Flux, Clear Sky','W m-2','NLWRCS'],
     546'7':['Brightness Temperature','K','BRTEMP'],
     547'8':['Downward Longwave Radiation Flux, Clear Sky','W m-2','DLWRFCS'],
     548'9':['Near IR albedo for diffuse radiation','%','NIRALBDIF'],
     549'10':['Near IR albedo for direct radiation','%','NIRALBDIR'],
     550'11':['Near IR albedo for direct radiation, geometric component','%','NIRALBDIRG'],
     551'12':['Near IR albedo for direct radiation, isotropic component','%','NIRALBDIRI'],
     552'13':['Near IR albedo for direct radiation, volumetric component','%','NIRALBDIRV'],
     553'14-191':['Reserved','unknown','unknown'],
     554'192-254':['Reserved for Local Use','unknown','unknown'],
     555'192':['Downward Longwave Radiation Flux','W m-2','DLWRF'],
     556'193':['Upward Longwave Radiation Flux','W m-2','ULWRF'],
     557'194':['Longwave Radiative Heating Rate','K s-1','LWHR'],
     558'195':['Clear Sky Upward Longwave Flux','W m-2','CSULF'],
     559'196':['Clear Sky Downward Longwave Flux','W m-2','CSDLF'],
     560'197':['Cloud Forcing Net Longwave Flux','W m-2','CFNLF'],
     561'255':['Missing','unknown','unknown'],
     562}
     563table_4_2_0_6  = {
     564'0':['Cloud Ice','kg m-2','CICE'],
     565'1':['Total Cloud Cover','%','TCDC'],
     566'2':['Convective Cloud Cover','%','CDCON'],
     567'3':['Low Cloud Cover','%','LCDC'],
     568'4':['Medium Cloud Cover','%','MCDC'],
     569'5':['High Cloud Cover','%','HCDC'],
     570'6':['Cloud Water','kg m-2','CWAT'],
     571'7':['Cloud Amount','%','CDCA'],
     572'8':['Cloud Type','See Table 4.203','CDCT'],
     573'9':['Thunderstorm Maximum Tops','m','TMAXT'],
     574'10':['Thunderstorm Coverage','See Table 4.204','THUNC'],
     575'11':['Cloud Base','m','CDCB'],
     576'12':['Cloud Top','m','CDCTOP'],
     577'13':['Ceiling','m','CEIL'],
     578'14':['Non-Convective Cloud Cover','%','CDLYR'],
     579'15':['Cloud Work Function','J kg-1','CWORK'],
     580'16':['Convective Cloud Efficiency','Proportion','CUEFI'],
     581'17':['Total Condensate','kg kg-1','TCONDO'],
     582'18':['Total Column Integrated Cloud Water','kg m-2','TCOLWO'],
     583'19':['Total Column Integrated Cloud Ice','kg m-2','TCOLIO'],
     584'20':['Total Column Integrated Condensate','kg m-2','TCOLC'],
     585'21':['Ice fraction of total condensate','Proportion','FICE'],
     586'22':['Cloud Cover','%','CDCC'],
     587'23':['Cloud Ice Mixing Ratio','kg kg-1','CDCIMR'],
     588'24':['Sunshine','Numeric','SUNS'],
     589'25':['Horizontal Extent of Cumulonimbus (CB)','%','CBHE'],
     590'26':['Height of Convective Cloud Base','m','HCONCB'],
     591'27':['Height of Convective Cloud Top','m','HCONCT'],
     592'28':['Number Concentration of Cloud Droplets','kg-1','NCONCD'],
     593'29':['Number Concentration of Cloud Ice','kg-1','NCCICE'],
     594'30':['Number Density of Cloud Droplets','m-3','NDENCD'],
     595'31':['Number Density of Cloud Ice','m-3','NDCICE'],
     596'32':['Fraction of Cloud Cover','Numeric','FRACCC'],
     597'33':['Sunshine Duration','s','SUNSD'],
     598'34':['Surface Long Wave Effective Total Cloudiness','Numeric','SLWTC'],
     599'35':['Surface Short Wave Effective Total Cloudiness','Numeric','SSWTC'],
     600'36':['Fraction of Stratiform Precipitation Cover','Proportion','FSTRPC'],
     601'37':['Fraction of Convective Precipitation Cover','Proportion','FCONPC'],
     602'38':['Mass Density of Cloud Droplets','kg m-3','MASSDCD'],
     603'39':['Mass Density of Cloud Ice','kg m-3','MASSDCI'],
     604'40':['Mass Density of Convective Cloud Water Droplets','kg m-3','MDCCWD'],
     605'41-46':['Reserved','unknown','unknown'],
     606'47':['Volume Fraction of Cloud Water Droplets','Numeric','VFRCWD'],
     607'48':['Volume Fraction of Cloud Ice Particles','Numeric','VFRCICE'],
     608'49':['Volume Fraction of Cloud (Ice and/or Water)','Numeric','VFRCIW'],
     609'50':['Fog','%','FOG'],
     610'51':['Sunshine Duration Fraction','Proportion','SUNFRAC'],
     611'52-191':['Reserved','unknown','unknown'],
     612'192-254':['Reserved for Local Use','unknown','unknown'],
     613'192':['Non-Convective Cloud Cover','%','CDLYR'],
     614'193':['Cloud Work Function','J kg-1','CWORK'],
     615'194':['Convective Cloud Efficiency','non-dim','CUEFI'],
     616'195':['Total Condensate','kg kg-1','TCOND'],
     617'196':['Total Column Integrated Cloud Water','kg m-2','TCOLW'],
     618'197':['Total Column Integrated Cloud Ice','kg m-2','TCOLI'],
     619'198':['Total Column Integrated Condensate','kg m-2','TCOLC'],
     620'199':['Ice fraction of total condensate','non-dim','FICE'],
     621'200':['Convective Cloud Mass Flux','Pa s-1','MFLUX'],
     622'201':['Sunshine Duration','s','SUNSD'],
     623'202':['Fog (LWC)','g kg-1','FOGLWC'],
     624'255':['Missing','unknown','unknown'],
     625}
     626table_4_2_0_7  = {
     627'0':['Parcel Lifted Index (to 500 hPa)','K','PLI'],
     628'1':['Best Lifted Index (to 500 hPa)','K','BLI'],
     629'2':['K Index','K','KX'],
     630'3':['KO Index','K','KOX'],
     631'4':['Total Totals Index','K','TOTALX'],
     632'5':['Sweat Index','Numeric','SX'],
     633'6':['Convective Available Potential Energy','J kg-1','CAPE'],
     634'7':['Convective Inhibition','J kg-1','CIN'],
     635'8':['Storm Relative Helicity','m2 s-2','HLCY'],
     636'9':['Energy Helicity Index','Numeric','EHLX'],
     637'10':['Surface Lifted Index','K','LFTX'],
     638'11':['Best (4 layer) Lifted Index','K','4LFTX'],
     639'12':['Richardson Number','Numeric','RI'],
     640'13':['Showalter Index','K','SHWINX'],
     641'14':['Reserved','unknown','unknown'],
     642'15':['Updraft Helicity','m2 s-2','UPHL'],
     643'16':['Bulk Richardson Number','Numeric','BLKRN'],
     644'17':['Gradient Richardson Number','Numeric','GRDRN'],
     645'18':['Flux Richardson Number','Numeric','FLXRN'],
     646'19':['Convective Available Potential Energy - Shear','m2 s-2','CONAPES'],
     647'20':['Thunderstorm Intensity Index','See Table 4.246','TIIDEX'],
     648'21':['Storm Severity Index','Numeric','SSI'],
     649'22':['Reciprocal Obukhov Length','m-1','RMOL'],
     650'23-191':['Reserved','unknown','unknown'],
     651'192-254':['Reserved for Local Use','unknown','unknown'],
     652'192':['Surface Lifted Index','K','LFTX'],
     653'193':['Best (4 layer) Lifted Index','K','4LFTX'],
     654'194':['Richardson Number','Numeric','RI'],
     655'195':['Convective Weather Detection Index','unknown','CWDI'],
     656'196':['Ultra Violet Index','W m-2','UVI'],
     657'197':['Updraft Helicity','m2 s-2','UPHL'],
     658'198':['Leaf Area Index','Numeric','LAI'],
     659'199':['Hourly Maximum of Updraft Helicity','m2 s-2','MXUPHL'],
     660'200':['Hourly Minimum of Updraft Helicity','m2 s-2','MNUPHL'],
     661'201':['Bourgoiun Negative Energy Layer (surface to freezing level)','J kg-1','BNEGELAY'],
     662'202':['Bourgoiun Positive Energy Layer (2k ft AGL to 400 hPa)','J kg-1','BPOSELAY'],
     663'203':['Downdraft CAPE','J kg-1','DCAPE'],
     664'204':['Effective Storm Relative Helicity','m2 s-2','EFHL'],
     665'205':['Enhanced Stretching Potential','Numeric','ESP'],
     666'206':['Critical Angle','Degree','CANGLE'],
     667'207':['Effective Surface Helicity','m2 s-2','E3KH'],
     668'208':['Significant Tornado Parameter with CIN - Effective Layer','numeric','STPC'],
     669'209':['Significant Hail Parameter','numeric','SIGH'],
     670'210':['Supercell Composite Parameter - Effective Layer','numeric','SCCP'],
     671'211':['Significant Tornado Parameter - Fixed Layer','numeric','SIGT'],
     672'212':['Mixed Layer (100 mb) Virtual LFC','numeric','MLFC'],
     673'255':['Missing','unknown','unknown'],
     674}
     675table_4_2_0_13  = {
     676'0':['Aerosol Type','See Table 4.205','AEROT'],
     677'1-191':['Reserved','unknown','unknown'],
     678'192-254':['Reserved for Local Use','unknown','unknown'],
     679'192':['Particulate matter (coarse)','µg m-3','PMTC'],
     680'193':['Particulate matter (fine)','µg m-3','PMTF'],
     681'194':['Particulate matter (fine)','log10 (µg m-3)','LPMTF'],
     682'195':['Integrated column particulate matter (fine)','log10 (µg m-3)','LIPMF'],
     683'255':['Missing','unknown','unknown'],
     684}
     685table_4_2_0_14  = {
     686'0':['Total Ozone','DU','TOZNE'],
     687'1':['Ozone Mixing Ratio','kg kg-1','O3MR'],
     688'2':['Total Column Integrated Ozone','DU','TCIOZ'],
     689'3-191':['Reserved','unknown','unknown'],
     690'192-254':['Reserved for Local Use','unknown','unknown'],
     691'192':['Ozone Mixing Ratio','kg kg-1','O3MR'],
     692'193':['Ozone Concentration','ppb','OZCON'],
     693'194':['Categorical Ozone Concentration','Non-Dim','OZCAT'],
     694'195':['Ozone Vertical Diffusion','kg kg-1 s-1','VDFOZ'],
     695'196':['Ozone Production','kg kg-1 s-1','POZ'],
     696'197':['Ozone Tendency','kg kg-1 s-1','TOZ'],
     697'198':['Ozone Production from Temperature Term','kg kg-1 s-1','POZT'],
     698'199':['Ozone Production from Column Ozone Term','kg kg-1 s-1','POZO'],
     699'200':['Ozone Daily Max from 1-hour Average','ppbV','OZMAX1'],
     700'201':['Ozone Daily Max from 8-hour Average','ppbV','OZMAX8'],
     701'202':['PM 2.5 Daily Max from 1-hour Average','μg m-3','PDMAX1'],
     702'203':['PM 2.5 Daily Max from 24-hour Average','μg m-3','PDMAX24'],
     703'204':['Acetaldehyde & Higher Aldehydes','ppbV','ALD2'],
     704'255':['Missing','unknown','unknown'],
     705}
     706table_4_2_0_15  = {
     707'0':['Base Spectrum Width','m s-1','BSWID'],
     708'1':['Base Reflectivity','dB','BREF'],
     709'2':['Base Radial Velocity','m s-1','BRVEL'],
     710'3':['Vertically-Integrated Liquid Water','kg m-2','VIL'],
     711'4':['Layer Maximum Base Reflectivity','dB','LMAXBR'],
     712'5':['Precipitation','kg m-2','PREC'],
     713'6':['Radar Spectra (1)','unknown','RDSP1'],
     714'7':['Radar Spectra (2)','unknown','RDSP2'],
     715'8':['Radar Spectra (3)','unknown','RDSP3'],
     716'9':['Reflectivity of Cloud Droplets','dB','RFCD'],
     717'10':['Reflectivity of Cloud Ice','dB','RFCI'],
     718'11':['Reflectivity of Snow','dB','RFSNOW'],
     719'12':['Reflectivity of Rain','dB','RFRAIN'],
     720'13':['Reflectivity of Graupel','dB','RFGRPL'],
     721'14':['Reflectivity of Hail','dB','RFHAIL'],
     722'15':['Hybrid Scan Reflectivity','dB','HSR'],
     723'16':['Hybrid Scan Reflectivity Height','m','HSRHT'],
     724'17':['Precipitation Rate','kg m-2 s-1','PRATERAD'],
     725'18':['Radar Data Quality Index','Proportion','RQI'],
     726'19':['Radar Data Quality Flag','See Table 4.106','RDQF'],
     727'20':['Layer Maximum Precipitation Rate','kg m-2 s-1','LMAXPRATE'],
     728'21-191':['Reserved','unknown','unknown'],
     729'192-254':['Reserved for Local Use','unknown','unknown'],
     730'192':['Vertically-Integrated Liquid Water','kg m-2','RADARVIL'],
     731'255':['Missing','unknown','unknown'],
     732}
     733table_4_2_0_16  = {
     734'0':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
     735'1':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
     736'2':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
     737'3':['Echo Top','m','RETOP'],
     738'4':['Reflectivity','dB','REFD'],
     739'5':['Composite reflectivity','dB','REFC'],
     740'6':['Precipitation Rate','kg m-2 s-1','PRATEFRAD'],
     741'7':['Layer Maximum Precipitation Rate','kg m-2 s-1','LMAXPRATEF'],
     742'8':['Layer Maximum Reflectivity','dB','LMAXREF'],
     743'9-191':['Reserved','unknown','unknown'],
     744'192-254':['Reserved for Local Use','unknown','unknown'],
     745'192':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
     746'193':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
     747'194':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
     748'195':['Reflectivity','dB','REFD'],
     749'196':['Composite reflectivity','dB','REFC'],
     750'197':['Echo Top','m','RETOP'],
     751'198':['Hourly Maximum of Simulated Reflectivity','dB','MAXREF'],
     752'199':['Hourly Maximum of Composite Reflectivity','dB','MAXREFC'],
     753'255':['Missing','unknown','unknown'],
     754}
     755table_4_2_0_17  = {
     756'0':['Lightning Strike Density','m-2 s-1','LTNGSD'],
     757'1':['Lightning Potential Index (LPI)','J kg-1','LTPINX'],
     758'2':['Cloud-to-Ground Lightning Flash Density','km-2 day-1','CDGDLTFD'],
     759'3':['Cloud-to-Cloud Lightning Flash Density','km-2 day-1','CDCDLTFD'],
     760'4':['Total Lightning Flash Density','km-2 day-1','TLGTFD'],
     761'5':['Subgrid-scale Lightning Potential Index','J kg-1','SLNGPIDX'],
     762'6-191':['Reserved','unknown','unknown'],
     763'192-254':['Reserved for Local Use','unknown','unknown'],
     764'192':['Lightning','non-dim','LTNG'],
     765'255':['Missing','unknown','unknown'],
     766}
     767table_4_2_0_18  = {
     768'0':['Air Concentration of Caesium 137','Bq m-3','ACCES'],
     769'1':['Air Concentration of Iodine 131','Bq m-3','ACIOD'],
     770'2':['Air Concentration of Radioactive Pollutant','Bq m-3','ACRADP'],
     771'3':['Ground Deposition of Caesium 137','Bq m-2','GDCES'],
     772'4':['Ground Deposition of Iodine 131','Bq m-2','GDIOD'],
     773'5':['Ground Deposition of Radioactive Pollutant','Bq m-2','GDRADP'],
     774'6':['Time Integrated Air Concentration of Cesium Pollutant','Bq s m-3','TIACCP'],
     775'7':['Time Integrated Air Concentration of Iodine Pollutant','Bq s m-3','TIACIP'],
     776'8':['Time Integrated Air Concentration of Radioactive Pollutant','Bq s m-3','TIACRP'],
     777'9':['Reserved','unknown','unknown'],
     778'10':['Air Concentration','Bq m-3','AIRCON'],
     779'11':['Wet Deposition','Bq m-2','WETDEP'],
     780'12':['Dry Deposition','Bq m-2','DRYDEP'],
     781'13':['Total Deposition (Wet + Dry)','Bq m-2','TOTLWD'],
     782'14':['Specific Activity Concentration','Bq kg-1','SACON'],
     783'15':['Maximum of Air Concentration in Layer','Bq m-3','MAXACON'],
     784'16':['Height of Maximum of Air Concentration','m','HMXACON'],
     785'17':['Column Integrated Air Concentration','Bq m-2','CIAIRC'],
     786'18':['Column Averaged Air Concentration in Layer','Bq m-3','CAACL'],
     787'19':['Deposition activity arrival','s','DEPACTA'],
     788'20':['Deposition activity ended','s','DEPACTE'],
     789'21':['Cloud activity arrival','s','CLDACTA'],
     790'22':['Cloud activity ended','s','CLDACTE'],
     791'23':['Effective dose rate','nSv h-1','EFFDOSER'],
     792'24':['Thyroid dose rate (adult)','nSv h-1','THYDOSER'],
     793'25':['Gamma dose rate (adult)','nSv h-1','GAMDOSER'],
     794'26':['Activity emission','Bq s-1','ACTEMM'],
     795'27-191':['Reserved','unknown','unknown'],
     796'192-254':['Reserved for Local Use','unknown','unknown'],
     797'255':['Missing','unknown','unknown'],
     798}
     799table_4_2_0_19  = {
     800'0':['Visibility','m','VIS'],
     801'1':['Albedo','%','ALBDO'],
     802'2':['Thunderstorm Probability','%','TSTM'],
     803'3':['Mixed Layer Depth','m','MIXHT'],
     804'4':['Volcanic Ash','See Table 4.206','VOLASH'],
     805'5':['Icing Top','m','ICIT'],
     806'6':['Icing Base','m','ICIB'],
     807'7':['Icing','See Table 4.207','ICI'],
     808'8':['Turbulence Top','m','TURBT'],
     809'9':['Turbulence Base','m','TURBB'],
     810'10':['Turbulence','See Table 4.208','TURB'],
     811'11':['Turbulent Kinetic Energy','J kg-1','TKE'],
     812'12':['Planetary Boundary Layer Regime','See Table 4.209','PBLREG'],
     813'13':['Contrail Intensity','See Table 4.210','CONTI'],
     814'14':['Contrail Engine Type','See Table 4.211','CONTET'],
     815'15':['Contrail Top','m','CONTT'],
     816'16':['Contrail Base','m','CONTB'],
     817'17':['Maximum Snow Albedo','%','MXSALB'],
     818'18':['Snow-Free Albedo','%','SNFALB'],
     819'19':['Snow Albedo','%','SALBD'],
     820'20':['Icing','%','ICIP'],
     821'21':['In-Cloud Turbulence','%','CTP'],
     822'22':['Clear Air Turbulence (CAT)','%','CAT'],
     823'23':['Supercooled Large Droplet Probability','%','SLDP'],
     824'24':['Convective Turbulent Kinetic Energy','J kg-1','CONTKE'],
     825'25':['Weather','See Table 4.225','WIWW'],
     826'26':['Convective Outlook','See Table 4.224','CONVO'],
     827'27':['Icing Scenario','See Table 4.227','ICESC'],
     828'28':['Mountain Wave Turbulence (Eddy Dissipation Rate)','m2/3 s-1','MWTURB'],
     829'29':['Clear Air Turbulence (CAT) (Eddy Dissipation Rate)','m2/3 s-1','CATEDR'],
     830'30':['Eddy Dissipation Parameter','m2/3 s-1','EDPARM'],
     831'31':['Maximum of Eddy Dissipation Parameter in Layer','m2/3 s-1','MXEDPRM'],
     832'32':['Highest Freezing Level','m','HIFREL'],
     833'33':['Visibility Through Liquid Fog','m','VISLFOG'],
     834'34':['Visibility Through Ice Fog','m','VISIFOG'],
     835'35':['Visibility Through Blowing Snow','m','VISBSN'],
     836'36':['Presence of Snow Squalls','See Table 4.222','PSNOWS'],
     837'37':['Icing Severity','See Table 4.228','ICESEV'],
     838'38':['Sky transparency index','See Table 4.214','SKYIDX'],
     839'39':['Seeing index','See Table 4.214','SEEINDEX'],
     840'40':['Snow level','m','SNOWLVL'],
     841'41':['Duct base height','m','DBHEIGHT'],
     842'42':['Trapping layer base height','m','TLBHEIGHT'],
     843'43':['Trapping layer top height','m','TLTHEIGHT'],
     844'44':['Mean vertical gradient of refractivity inside trapping layer','m-1','MEANVGRTL'],
     845'45':['Minimum vertical gradient of refractivity inside trapping layer','m-1','MINVGRTL'],
     846'46':['Net radiation flux','W m-2','NETRADFLUX'],
     847'47':['Global irradiance on tilted surfaces','W m-2','GLIRRTS'],
     848'48':['Top of persistent contrails','m','PCONTT'],
     849'49':['Base of persistent contrails','m','PCONTB'],
     850'50':['Convectively-induced turbulence (CIT) (eddy dissipation rate)','m2/3 s-1','CITEDR'],
     851'51':['Visibility Through Precipitation','m','VISPCP'],
     852'52':['Hail Kinetic Energy Flux','J m-2 s-1','HAILKEF'],
     853'53-191':['Reserved','unknown','unknown'],
     854'192-254':['Reserved for Local Use','unknown','unknown'],
     855'192':['Maximum Snow Albedo','%','MXSALB'],
     856'193':['Snow-Free Albedo','%','SNFALB'],
     857'194':['Slight risk convective outlook','categorical','SRCONO'],
     858'195':['Moderate risk convective outlook','categorical','MRCONO'],
     859'196':['High risk convective outlook','categorical','HRCONO'],
     860'197':['Tornado probability','%','TORPROB'],
     861'198':['Hail probability','%','HAILPROB'],
     862'199':['Wind probability','%','WINDPROB'],
     863'200':['Significant Tornado probability','%','STORPROB'],
     864'201':['Significant Hail probability','%','SHAILPRO'],
     865'202':['Significant Wind probability','%','SWINDPRO'],
     866'203':['Categorical Thunderstorm','Code table 4.222','TSTMC'],
     867'204':['Number of mixed layers next to surface','integer','MIXLY'],
     868'205':['Flight Category','unknown','FLGHT'],
     869'206':['Confidence - Ceiling','unknown','CICEL'],
     870'207':['Confidence - Visibility','unknown','CIVIS'],
     871'208':['Confidence - Flight Category','unknown','CIFLT'],
     872'209':['Low-Level aviation interest','unknown','LAVNI'],
     873'210':['High-Level aviation interest','unknown','HAVNI'],
     874'211':['Visible, Black Sky Albedo','%','SBSALB'],
     875'212':['Visible, White Sky Albedo','%','SWSALB'],
     876'213':['Near IR, Black Sky Albedo','%','NBSALB'],
     877'214':['Near IR, White Sky Albedo','%','NWSALB'],
     878'215':['Total Probability of Severe Thunderstorms (Days 2,3)','%','PRSVR'],
     879'216':['Total Probability of Extreme Severe Thunderstorms (Days 2,3)','%','PRSIGSVR'],
     880'217':['Supercooled Large Droplet (SLD) Icing','See Table 4.207','SIPD'],
     881'218':['Radiative emissivity','unknown','EPSR'],
     882'219':['Turbulence Potential Forecast Index','unknown','TPFI'],
     883'220':['Categorical Severe Thunderstorm','Code table 4.222','SVRTS'],
     884'221':['Probability of Convection','%','PROCON'],
     885'222':['Convection Potential','Code table 4.222','CONVP'],
     886'223-231':['Reserved','unknown','unknown'],
     887'232':['Volcanic Ash Forecast Transport and Dispersion','log10 (kg m-3)','VAFTD'],
     888'233':['Icing probability','non-dim','ICPRB'],
     889'234':['Icing Severity','non-dim','ICSEV'],
     890'235':['Joint Fire Weather Probability','%','JFWPRB'],
     891'236':['Snow Level','m','SNOWLVL'],
     892'237':['Dry Thunderstorm Probability','%','DRYTPROB'],
     893'238':['Ellrod Index','unknown','ELLINX'],
     894'239':['Craven-Wiedenfeld Aggregate Severe Parameter','Numeric','CWASP'],
     895'240':['Continuous Icing Severity','non-dim','ICESEVCON'],
     896'255':['Missing','unknown','unknown'],
     897}
     898table_4_2_0_20  = {
     899'0':['Mass Density (Concentration)','kg m-3','MASSDEN'],
     900'1':['Column-Integrated Mass Density','kg m-2','COLMD'],
     901'2':['Mass Mixing Ratio (Mass Fraction in Air)','kg kg-1','MASSMR'],
     902'3':['Atmosphere Emission Mass Flux','kg m-2s-1','AEMFLX'],
     903'4':['Atmosphere Net Production Mass Flux','kg m-2s-1','ANPMFLX'],
     904'5':['Atmosphere Net Production And Emision Mass Flux','kg m-2s-1','ANPEMFLX'],
     905'6':['Surface Dry Deposition Mass Flux','kg m-2s-1','SDDMFLX'],
     906'7':['Surface Wet Deposition Mass Flux','kg m-2s-1','SWDMFLX'],
     907'8':['Atmosphere Re-Emission Mass Flux','kg m-2s-1','AREMFLX'],
     908'9':['Wet Deposition by Large-Scale Precipitation Mass Flux','kg m-2s-1','WLSMFLX'],
     909'10':['Wet Deposition by Convective Precipitation Mass Flux','kg m-2s-1','WDCPMFLX'],
     910'11':['Sedimentation Mass Flux','kg m-2s-1','SEDMFLX'],
     911'12':['Dry Deposition Mass Flux','kg m-2s-1','DDMFLX'],
     912'13':['Transfer From Hydrophobic to Hydrophilic','kg kg-1s-1','TRANHH'],
     913'14':['Transfer From SO2 (Sulphur Dioxide) to SO4 (Sulphate)','kg kg-1s-1','TRSDS'],
     914'15':['Dry deposition velocity','m s-1','DDVEL'],
     915'16':['Mass mixing ratio with respect to dry air','kg kg-1','MSSRDRYA'],
     916'17':['Mass mixing ratio with respect to wet air','kg kg-1','MSSRWETA'],
     917'18':['Potential of hydrogen (pH)','pH','POTHPH'],
     918'19':['Loss Rate Due to Reaction with Hydroxyl Radical (OH)','kg kg-1 s-1','LRATEOH'],
     919'20-49':['Reserved','unknown','unknown'],
     920'50':['Amount in Atmosphere','mol','AIA'],
     921'51':['Concentration In Air','mol m-3','CONAIR'],
     922'52':['Volume Mixing Ratio (Fraction in Air)','mol mol-1','VMXR'],
     923'53':['Chemical Gross Production Rate of Concentration','mol m-3s-1','CGPRC'],
     924'54':['Chemical Gross Destruction Rate of Concentration','mol m-3s-1','CGDRC'],
     925'55':['Surface Flux','mol m-2s-1','SFLUX'],
     926'56':['Changes Of Amount in Atmosphere','mol s-1','COAIA'],
     927'57':['Total Yearly Average Burden of The Atmosphere>','mol','TYABA'],
     928'58':['Total Yearly Average Atmospheric Loss','mol s-1','TYAAL'],
     929'59':['Aerosol Number Concentration','m-3','ANCON'],
     930'60':['Aerosol Specific Number Concentration','kg-1','ASNCON'],
     931'61':['Maximum of Mass Density','kg m-3','MXMASSD'],
     932'62':['Height of Mass Density','m','HGTMD'],
     933'63':['Column-Averaged Mass Density in Layer','kg m-3','CAVEMDL'],
     934'64':['Mole fraction with respect to dry air','mol mol-1','MOLRDRYA'],
     935'65':['Mole fraction with respect to wet air','mol mol-1','MOLRWETA'],
     936'66':['Column-integrated in-cloud scavenging rate by precipitation','kg m-2 s-1','CINCLDSP'],
     937'67':['Column-integrated below-cloud scavenging rate by precipitation','kg m-2 s-1','CBLCLDSP'],
     938'68':['Column-integrated release rate from evaporating precipitation','kg m-2 s-1','CIRELREP'],
     939'69':['Column-integrated in-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CINCSLSP'],
     940'70':['Column-integrated below-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CBECSLSP'],
     941'71':['Column-integrated release rate from evaporating large-scale precipitation','kg m-2 s-1','CRERELSP'],
     942'72':['Column-integrated in-cloud scavenging rate by convective precipitation','kg m-2 s-1','CINCSRCP'],
     943'73':['Column-integrated below-cloud scavenging rate by convective precipitation','kg m-2 s-1','CBLCSRCP'],
     944'74':['Column-integrated release rate from evaporating convective precipitation','kg m-2 s-1','CIRERECP'],
     945'75':['Wildfire flux','kg m-2 s-1','WFIREFLX'],
     946'76':['Emission Rate','kg kg-1 s-1','EMISFLX'],
     947'77':['Surface Emission flux','kg m-2 s-1','SFCEFLX'],
     948'78':['Column integrated eastward mass flux','kg m-2 s-1','CEMF'],
     949'79':['Column integrated northward mass flux','kg m-2 s-1','CNMF'],
     950'80':['Column integrated divergence of mass flux','kg m-2 s-1','CDIVMF'],
     951'81':['Column integrated net source','kg m-2 s-1','CNETS'],
     952'82':['Sink mass flux','kg m-2 s-1','SNKMFLX'],
     953'83':['Source mass flux','kg m-2 s-1','SRCMFLX'],
     954'84':['Volume-mean total column mixing ratio','mol mol-1','VTCOLMIXR'],
     955'85-99':['Reserved','unknown','unknown'],
     956'100':['Surface Area Density (Aerosol)','m-1','SADEN'],
     957'101':['Vertical Visual Range','m','ATMTK'],
     958'102':['Aerosol Optical Thickness','Numeric','AOTK'],
     959'103':['Single Scattering Albedo','Numeric','SSALBK'],
     960'104':['Asymmetry Factor','Numeric','ASYSFK'],
     961'105':['Aerosol Extinction Coefficient','m-1','AECOEF'],
     962'106':['Aerosol Absorption Coefficient','m-1','AACOEF'],
     963'107':['Aerosol Lidar Backscatter from Satellite','m-1sr-1','ALBSAT'],
     964'108':['Aerosol Lidar Backscatter from the Ground','m-1sr-1','ALBGRD'],
     965'109':['Aerosol Lidar Extinction from Satellite','m-1','ALESAT'],
     966'110':['Aerosol Lidar Extinction from the Ground','m-1','ALEGRD'],
     967'111':['Angstrom Exponent','Numeric','ANGSTEXP'],
     968'112':['Absorption Aerosol Optical Thickness','Numeric','SCTAOTK'],
     969'113':['Aerosol Backscatter Coefficient','m-1 sr-1','ABCOEF'],
     970'114-191':['Reserved','unknown','unknown'],
     971'192-254':['Reserved for Local Use','unknown','unknown'],
     972'255':['Missing','unknown','unknown'],
     973}
     974table_4_2_0_190  = {
     975'0':['Arbitrary Text String','CCITTIA5','ATEXT'],
     976'1-191':['Reserved','unknown','unknown'],
     977'192-254':['Reserved for Local Use','unknown','unknown'],
     978'255':['Missing','unknown','unknown'],
     979}
     980table_4_2_0_191  = {
     981'0':['Seconds prior to initial reference time (defined in Section 1)','s','TSEC'],
     982'1':['Geographical Latitude','° N','GEOLAT'],
     983'2':['Geographical Longitude','° E','GEOLON'],
     984'3':['Days Since Last Observation','d','DSLOBS'],
     985'4':['Tropical cyclone density track','Numeric','TCDTRACK'],
     986'5':['Hurricane track in spatiotemporal vicinity','boolean','HURTSV'],
     987'6':['Tropical storm track in spatiotemporal vicinity','boolean','TSTSV'],
     988'7':['Tropical depression track in spatiotemporal vicinity','boolean','TDTSV'],
     989'8-191':['Reserved','unknown','unknown'],
     990'192-254':['Reserved for Local Use','unknown','unknown'],
     991'192':['Latitude (-90 to 90)','°','NLAT'],
     992'193':['East Longitude (0 to 360)','°','ELON'],
     993'194':['Seconds prior to initial reference time','s','RTSEC'],
     994'195':['Model Layer number (From bottom up)','unknown','MLYNO'],
     995'196':['Latitude (nearest neighbor) (-90 to 90)','°','NLATN'],
     996'197':['East Longitude (nearest neighbor) (0 to 360)','°','ELONN'],
     997'255':['Missing','unknown','unknown'],
     998}
     999table_4_2_0_192  = {
    1000'1':['Covariance between zonal and meridional components of the wind. Defined as [uv]-[u][v], where "[]" indicates the mean over the indicated time span.','m2/s2','COVMZ'],
    1001'2':['Covariance between zonal component of the wind and temperature. Defined as [uT]-[u][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTZ'],
    1002'3':['Covariance between meridional component of the wind and temperature. Defined as [vT]-[v][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTM'],
    1003'4':['Covariance between temperature and vertical component of the wind. Defined as [wT]-[w][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTW'],
    1004'5':['Covariance between zonal and zonal components of the wind. Defined as [uu]-[u][u], where "[]" indicates the mean over the indicated time span.','m2/s2','COVZZ'],
    1005'6':['Covariance between meridional and meridional components of the wind. Defined as [vv]-[v][v], where "[]" indicates the mean over the indicated time span.','m2/s2','COVMM'],
    1006'7':['Covariance between specific humidity and zonal components of the wind. Defined as [uq]-[u][q], where "[]" indicates the mean over the indicated time span.','kg/kg*m/s','COVQZ'],
    1007'8':['Covariance between specific humidity and meridional components of the wind. Defined as [vq]-[v][q], where "[]" indicates the mean over the indicated time span.','kg/kg*m/s','COVQM'],
    1008'9':['Covariance between temperature and vertical components of the wind. Defined as [ΩT]-[Ω][T], where "[]" indicates the mean over the indicated time span.','K*Pa/s','COVTVV'],
    1009'10':['Covariance between specific humidity and vertical components of the wind. Defined as [Ωq]-[Ω][q], where "[]" indicates the mean over the indicated time span.','kg/kg*Pa/s','COVQVV'],
    1010'11':['Covariance between surface pressure and surface pressure. Defined as [Psfc]-[Psfc][Psfc], where "[]" indicates the mean over the indicated time span.','Pa*Pa','COVPSPS'],
    1011'12':['Covariance between specific humidity and specific humidy. Defined as [qq]-[q][q], where "[]" indicates the mean over the indicated time span.','kg/kg*kg/kg','COVQQ'],
    1012'13':['Covariance between vertical and vertical components of the wind. Defined as [ΩΩ]-[Ω][Ω], where "[]" indicates the mean over the indicated time span.','Pa2/s2','COVVVVV'],
    1013'14':['Covariance between temperature and temperature. Defined as [TT]-[T][T], where "[]" indicates the mean over the indicated time span.','K*K','COVTT'],
    1014'255':['Missing','unknown','unknown'],
    1015}
    1016# ----------------------------------------------------------------------------------------
    1017# Source: https://github.com/NOAA-EMC/NCEPLIBS-wgrib2/blob/develop/wgrib2/NDFD_gribtab.dat
    1018#         and
    1019#         https://vlab.noaa.gov/web/mdl/ndfd-grib-all-sections#section-4-product-definition-section
    1020#
    1021# The dictionary names are in the following format:
    1022#     table_4_2_<discipline>_<parameterCategory>_ndfd
    1023# ----------------------------------------------------------------------------------------
    1024table_4_2_0_0_ndfd = {
    1025'193':['Apparent Temperature','K','APPT'],
    1026}
    1027
    1028table_4_2_0_1_ndfd = {
    1029'192':['Weather Information','WxInfo','WX'],
    1030}
    1031
    1032table_4_2_0_19_ndfd = {
    1033'194':['Convective Hazard Outlook','categorical','CONVOUTLOOK'],
    1034'197':['Probability of Tornado','%','PTORNADO'],
    1035'198':['Probability of Hail','%','PHAIL'],
    1036'199':['Probability of Damaging Wind','%','PWIND'],
    1037'200':['Probability of Extreme Tornado','%','PXTRMTORN'],
    1038'201':['Probability of Extreme Hail','%','PXTRMHAIL'],
    1039'202':['Probability of Extreme Wind','%','PXTRMWIND'],
    1040'215':['Total Probability of Severe Thunderstorms','%','TOTALSVRPROB'],
    1041'216':['Total Probability of Extreme Severe Thunderstorms','%','TOTALXTRMPROB'],
    1042'217':['Watch Warning Advisory','WxInfo','WWA'],
    1043}
    1044
    1045table_4_2_0_192_ndfd = {
    1046'192':['Critical Fire Weather','','FIREWX'],
    1047'194':['Dry Lightning','','DRYLIGHTNING'],
    1048}

table_4_2_0_0 = {'0': ['Temperature', 'K', 'TMP'], '1': ['Virtual Temperature', 'K', 'VTMP'], '2': ['Potential Temperature', 'K', 'POT'], '3': ['Pseudo-Adiabatic Potential Temperature (or Equivalent Potential Temperature)', 'K', 'EPOT'], '4': ['Maximum Temperature', 'K', 'TMAX'], '5': ['Minimum Temperature', 'K', 'TMIN'], '6': ['Dew Point Temperature', 'K', 'DPT'], '7': ['Dew Point Depression (or Deficit)', 'K', 'DEPR'], '8': ['Lapse Rate', 'K m-1', 'LAPR'], '9': ['Temperature Anomaly', 'K', 'TMPA'], '10': ['Latent Heat Net Flux', 'W m-2', 'LHTFL'], '11': ['Sensible Heat Net Flux', 'W m-2', 'SHTFL'], '12': ['Heat Index', 'K', 'HEATX'], '13': ['Wind Chill Factor', 'K', 'WCF'], '14': ['Minimum Dew Point Depression', 'K', 'MINDPD'], '15': ['Virtual Potential Temperature', 'K', 'VPTMP'], '16': ['Snow Phase Change Heat Flux', 'W m-2', 'SNOHF'], '17': ['Skin Temperature', 'K', 'SKINT'], '18': ['Snow Temperature (top of snow)', 'K', 'SNOT'], '19': ['Turbulent Transfer Coefficient for Heat', 'Numeric', 'TTCHT'], '20': ['Turbulent Diffusion Coefficient for Heat', 'm2s-1', 'TDCHT'], '21': ['Apparent Temperature', 'K', 'APTMP'], '22': ['Temperature Tendency due to Shortwave Radiation', 'K s-1', 'TTSWR'], '23': ['Temperature Tendency due to Longwave Radiation', 'K s-1', 'TTLWR'], '24': ['Temperature Tendency due to Shortwave Radiation, Clear Sky', 'K s-1', 'TTSWRCS'], '25': ['Temperature Tendency due to Longwave Radiation, Clear Sky', 'K s-1', 'TTLWRCS'], '26': ['Temperature Tendency due to parameterizations', 'K s-1', 'TTPARM'], '27': ['Wet-Bulb Temperature', 'K', 'WETBT'], '28': ['Unbalanced Component of Temperature', 'K', 'UCTMP'], '29': ['Temperature Advection', 'K s-1', 'TMPADV'], '30': ['Latent Heat Net Flux Due to Evaporation', 'W m-2', 'LHFLXE'], '31': ['Latent Heat Net Flux Due to Sublimation', 'W m-2', 'LHFLXS'], '32': ['Wet-Bulb Potential Temperature', 'K', 'WETBPT'], '33-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Snow Phase Change Heat Flux', 'W m-2', 'SNOHF'], '193': ['Temperature Tendency by All Radiation', 'K s-1', 'TTRAD'], '194': ['Relative Error Variance', 'unknown', 'REV'], '195': ['Large Scale Condensate Heating Rate', 'K s-1', 'LRGHR'], '196': ['Deep Convective Heating Rate', 'K s-1', 'CNVHR'], '197': ['Total Downward Heat Flux at Surface', 'W m-2', 'THFLX'], '198': ['Temperature Tendency by All Physics', 'K s-1', 'TTDIA'], '199': ['Temperature Tendency by Non-Radiation Physics', 'K s-1', 'TTPHY'], '200': ['Standard Dev. of IR Temp. over 1x1 deg. area', 'K', 'TSD1D'], '201': ['Shallow Convective Heating Rate', 'K s-1', 'SHAHR'], '202': ['Vertical Diffusion Heating rate', 'K s-1', 'VDFHR'], '203': ['Potential Temperature at Top of Viscous Sublayer', 'K', 'THZ0'], '204': ['Tropical Cyclone Heat Potential', 'J m-2 K', 'TCHP'], '205': ['Effective Layer (EL) Temperature', 'C', 'ELMELT'], '206': ['Wet Bulb Globe Temperature', 'K', 'WETGLBT'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_1 = {'0': ['Specific Humidity', 'kg kg-1', 'SPFH'], '1': ['Relative Humidity', '%', 'RH'], '2': ['Humidity Mixing Ratio', 'kg kg-1', 'MIXR'], '3': ['Precipitable Water', 'kg m-2', 'PWAT'], '4': ['Vapor Pressure', 'Pa', 'VAPP'], '5': ['Saturation Deficit', 'Pa', 'SATD'], '6': ['Evaporation', 'kg m-2', 'EVP'], '7': ['Precipitation Rate', 'kg m-2 s-1', 'PRATE'], '8': ['Total Precipitation', 'kg m-2', 'APCP'], '9': ['Large-Scale Precipitation (non-convective)', 'kg m-2', 'NCPCP'], '10': ['Convective Precipitation', 'kg m-2', 'ACPCP'], '11': ['Snow Depth', 'm', 'SNOD'], '12': ['Snowfall Rate Water Equivalent', 'kg m-2 s-1', 'SRWEQ'], '13': ['Water Equivalent of Accumulated Snow Depth', 'kg m-2', 'WEASD'], '14': ['Convective Snow', 'kg m-2', 'SNOC'], '15': ['Large-Scale Snow', 'kg m-2', 'SNOL'], '16': ['Snow Melt', 'kg m-2', 'SNOM'], '17': ['Snow Age', 'day', 'SNOAG'], '18': ['Absolute Humidity', 'kg m-3', 'ABSH'], '19': ['Precipitation Type', 'See Table 4.201', 'PTYPE'], '20': ['Integrated Liquid Water', 'kg m-2', 'ILIQW'], '21': ['Condensate', 'kg kg-1', 'TCOND'], '22': ['Cloud Mixing Ratio', 'kg kg-1', 'CLMR'], '23': ['Ice Water Mixing Ratio', 'kg kg-1', 'ICMR'], '24': ['Rain Mixing Ratio', 'kg kg-1', 'RWMR'], '25': ['Snow Mixing Ratio', 'kg kg-1', 'SNMR'], '26': ['Horizontal Moisture Convergence', 'kg kg-1 s-1', 'MCONV'], '27': ['Maximum Relative Humidity', '%', 'MAXRH'], '28': ['Maximum Absolute Humidity', 'kg m-3', 'MAXAH'], '29': ['Total Snowfall', 'm', 'ASNOW'], '30': ['Precipitable Water Category', 'See Table 4.202', 'PWCAT'], '31': ['Hail', 'm', 'HAIL'], '32': ['Graupel', 'kg kg-1', 'GRLE'], '33': ['Categorical Rain', 'Code table 4.222', 'CRAIN'], '34': ['Categorical Freezing Rain', 'Code table 4.222', 'CFRZR'], '35': ['Categorical Ice Pellets', 'Code table 4.222', 'CICEP'], '36': ['Categorical Snow', 'Code table 4.222', 'CSNOW'], '37': ['Convective Precipitation Rate', 'kg m-2 s-1', 'CPRAT'], '38': ['Horizontal Moisture Divergence', 'kg kg-1 s-1', 'MDIVER'], '39': ['Percent frozen precipitation', '%', 'CPOFP'], '40': ['Potential Evaporation', 'kg m-2', 'PEVAP'], '41': ['Potential Evaporation Rate', 'W m-2', 'PEVPR'], '42': ['Snow Cover', '%', 'SNOWC'], '43': ['Rain Fraction of Total Cloud Water', 'Proportion', 'FRAIN'], '44': ['Rime Factor', 'Numeric', 'RIME'], '45': ['Total Column Integrated Rain', 'kg m-2', 'TCOLR'], '46': ['Total Column Integrated Snow', 'kg m-2', 'TCOLS'], '47': ['Large Scale Water Precipitation (Non-Convective)', 'kg m-2', 'LSWP'], '48': ['Convective Water Precipitation', 'kg m-2', 'CWP'], '49': ['Total Water Precipitation', 'kg m-2', 'TWATP'], '50': ['Total Snow Precipitation', 'kg m-2', 'TSNOWP'], '51': ['Total Column Water (Vertically Integrated Total Water (Vapor + Cloud Water/Ice))', 'kg m-2', 'TCWAT'], '52': ['Total Precipitation Rate', 'kg m-2 s-1', 'TPRATE'], '53': ['Total Snowfall Rate Water Equivalent', 'kg m-2 s-1', 'TSRWE'], '54': ['Large Scale Precipitation Rate', 'kg m-2 s-1', 'LSPRATE'], '55': ['Convective Snowfall Rate Water Equivalent', 'kg m-2 s-1', 'CSRWE'], '56': ['Large Scale Snowfall Rate Water Equivalent', 'kg m-2 s-1', 'LSSRWE'], '57': ['Total Snowfall Rate', 'm s-1', 'TSRATE'], '58': ['Convective Snowfall Rate', 'm s-1', 'CSRATE'], '59': ['Large Scale Snowfall Rate', 'm s-1', 'LSSRATE'], '60': ['Snow Depth Water Equivalent', 'kg m-2', 'SDWE'], '61': ['Snow Density', 'kg m-3', 'SDEN'], '62': ['Snow Evaporation', 'kg m-2', 'SEVAP'], '63': ['Reserved', 'unknown', 'unknown'], '64': ['Total Column Integrated Water Vapor', 'kg m-2', 'TCIWV'], '65': ['Rain Precipitation Rate', 'kg m-2 s-1', 'RPRATE'], '66': ['Snow Precipitation Rate', 'kg m-2 s-1', 'SPRATE'], '67': ['Freezing Rain Precipitation Rate', 'kg m-2 s-1', 'FPRATE'], '68': ['Ice Pellets Precipitation Rate', 'kg m-2 s-1', 'IPRATE'], '69': ['Total Column Integrated Cloud Water', 'kg m-2', 'TCOLW'], '70': ['Total Column Integrated Cloud Ice', 'kg m-2', 'TCOLI'], '71': ['Hail Mixing Ratio', 'kg kg-1', 'HAILMXR'], '72': ['Total Column Integrated Hail', 'kg m-2', 'TCOLH'], '73': ['Hail Precipitation Rate', 'kg m-2 s-1', 'HAILPR'], '74': ['Total Column Integrated Graupel', 'kg m-2', 'TCOLG'], '75': ['Graupel (Snow Pellets) Precipitation Rate', 'kg m-2 s-1', 'GPRATE'], '76': ['Convective Rain Rate', 'kg m-2 s-1', 'CRRATE'], '77': ['Large-Scale Rain Rate', 'kg m-2 s-1', 'LSRRATE'], '78': ['Total Column Integrated Water (all components including precipitation)', 'kg m-2', 'TCOLWA'], '79': ['Evaporation Rate', 'kg m-2 s-1', 'EVARATE'], '80': ['Total Condensate', 'kg kg-1', 'TOTCON'], '81': ['Total Column Integrated Condensate', 'kg m-2', 'TCICON'], '82': ['Cloud Ice Mixing Ratio', 'kg kg-1', 'CIMIXR'], '83': ['Specific Cloud Liquid Water Content', 'kg kg-1', 'SCLLWC'], '84': ['Specific Cloud Ice Water Content', 'kg kg-1', 'SCLIWC'], '85': ['Specific Rain Water Content', 'kg kg-1', 'SRAINW'], '86': ['Specific Snow Water Content', 'kg kg-1', 'SSNOWW'], '87': ['Stratiform Precipitation Rate', 'kg m-2 s-1', 'STRPRATE'], '88': ['Categorical Convective Precipitation', 'Code table 4.222', 'CATCP'], '89': ['Reserved', 'unknown', 'unknown'], '90': ['Total Kinematic Moisture Flux', 'kg kg-1 m s-1', 'TKMFLX'], '91': ['U-Component (Zonal) Kinematic Moisture Flux', 'kg kg-1 m s-1', 'UKMFLX'], '92': ['V-Component (Meridional) Kinematic Moisture Flux', 'kg kg-1 m s-1', 'VKMFLX'], '93': ['Relative Humidity With Respect to Water', '%', 'RHWATER'], '94': ['Relative Humidity With Respect to Ice', '%', 'RHICE'], '95': ['Freezing or Frozen Precipitation Rate', 'kg m-2 s-1', 'FZPRATE'], '96': ['Mass Density of Rain', 'kg m-3', 'MASSDR'], '97': ['Mass Density of Snow', 'kg m-3', 'MASSDS'], '98': ['Mass Density of Graupel', 'kg m-3', 'MASSDG'], '99': ['Mass Density of Hail', 'kg m-3', 'MASSDH'], '100': ['Specific Number Concentration of Rain', 'kg-1', 'SPNCR'], '101': ['Specific Number Concentration of Snow', 'kg-1', 'SPNCS'], '102': ['Specific Number Concentration of Graupel', 'kg-1', 'SPNCG'], '103': ['Specific Number Concentration of Hail', 'kg-1', 'SPNCH'], '104': ['Number Density of Rain', 'm-3', 'NUMDR'], '105': ['Number Density of Snow', 'm-3', 'NUMDS'], '106': ['Number Density of Graupel', 'm-3', 'NUMDG'], '107': ['Number Density of Hail', 'm-3', 'NUMDH'], '108': ['Specific Humidity Tendency due to Parameterizations', 'kg kg-1 s-1', 'SHTPRM'], '109': ['Mass Density of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Volume of Air', 'kg m-3', 'MDLWHVA'], '110': ['Specific Mass of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Moist Air', 'kg kg-1', 'SMLWHMA'], '111': ['Mass Mixing Ratio of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Dry Air', 'kg kg-1', 'MMLWHDA'], '112': ['Mass Density of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Volume of Air', 'kg m-3', 'MDLWGVA'], '113': ['Specific Mass of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Moist Air', 'kg kg-1', 'SMLWGMA'], '114': ['Mass Mixing Ratio of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Mass of Dry Air', 'kg kg-1', 'MMLWGDA'], '115': ['Mass Density of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Volume of Air', 'kg m-3', 'MDLWSVA'], '116': ['Specific Mass of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Moist Air', 'kg kg-1', 'SMLWSMA'], '117': ['Mass Mixing Ratio of Liquid Water Coating on Snow Expressed as Mass of Liquid Water per Unit Mass of Dry Air', 'kg kg-1', 'MMLWSDA'], '118': ['Unbalanced Component of Specific Humidity', 'kg kg-1', 'UNCSH'], '119': ['Unbalanced Component of Specific Cloud Liquid Water content', 'kg kg-1', 'UCSCLW'], '120': ['Unbalanced Component of Specific Cloud Ice Water content', 'kg kg-1', 'UCSCIW'], '121': ['Fraction of Snow Cover', 'Proportion', 'FSNOWC'], '122': ['Precipitation intensity index', 'See Table 4.247', 'PIIDX'], '123': ['Dominant precipitation type', 'See Table 4.201', 'DPTYPE'], '124': ['Presence of showers', 'See Table 4.222', 'PSHOW'], '125': ['Presence of blowing snow', 'See Table 4.222', 'PBSNOW'], '126': ['Presence of blizzard', 'See Table 4.222', 'PBLIZZ'], '127': ['Ice pellets (non-water equivalent) precipitation rate', 'm s-1', 'ICEP'], '128': ['Total solid precipitation rate', 'kg m-2 s-1', 'TSPRATE'], '129': ['Effective Radius of Cloud Water', 'm', 'EFRCWAT'], '130': ['Effective Radius of Rain', 'm', 'EFRRAIN'], '131': ['Effective Radius of Cloud Ice', 'm', 'EFRCICE'], '132': ['Effective Radius of Snow', 'm', 'EFRSNOW'], '133': ['Effective Radius of Graupel', 'm', 'EFRGRL'], '134': ['Effective Radius of Hail', 'm', 'EFRHAIL'], '135': ['Effective Radius of Subgrid Liquid Clouds', 'm', 'EFRSLC'], '136': ['Effective Radius of Subgrid Ice Clouds', 'm', 'EFRSICEC'], '137': ['Effective Aspect Ratio of Rain', 'unknown', 'EFARRAIN'], '138': ['Effective Aspect Ratio of Cloud Ice', 'unknown', 'EFARCICE'], '139': ['Effective Aspect Ratio of Snow', 'unknown', 'EFARSNOW'], '140': ['Effective Aspect Ratio of Graupel', 'unknown', 'EFARGRL'], '141': ['Effective Aspect Ratio of Hail', 'unknown', 'EFARHAIL'], '142': ['Effective Aspect Ratio of Subgrid Ice Clouds', 'unknown', 'EFARSIC'], '143': ['Potential evaporation rate', 'kg m-2 s-1', 'PERATE'], '144': ['Specific rain water content (convective)', 'kg kg-1', 'SRWATERC'], '145': ['Specific snow water content (convective)', 'kg kg-1', 'SSNOWWC'], '146': ['Cloud ice precipitation rate', 'kg m-2 s-1', 'CICEPR'], '147': ['Character of precipitation', 'See Table 4.249', 'CHPRECIP'], '148': ['Snow evaporation rate', 'kg m-2 s-1', 'SNOWERAT'], '149': ['Cloud water mixing ratio', 'kg kg-1', 'CWATERMR'], '150': ['Column integrated eastward water vapor mass flux', 'kg m-1s-1', 'CEWVMF'], '151': ['Column integrated northward water vapor mass flux', 'kg m-1s-1', 'CNWVMF'], '152': ['Column integrated eastward cloud liquid water mass flux', 'kg m-1s-1', 'CECLWMF'], '153': ['Column integrated northward cloud liquid water mass flux', 'kg m-1s-1', 'CNCLWMF'], '154': ['Column integrated eastward cloud ice mass flux', 'kg m-1s-1', 'CECIMF'], '155': ['Column integrated northward cloud ice mass flux', 'kg m-1s-1', 'CNCIMF'], '156': ['Column integrated eastward rain mass flux', 'kg m-1s-1', 'CERMF'], '157': ['Column integrated northward rain mass flux', 'kg m-1s-1', 'CNRMF'], '158': ['Column integrated eastward snow mass flux', 'kg m-1s-1', 'CEFMF'], '159': ['Column integrated northward snow mass flux', 'kg m-1s-1', 'CNSMF'], '160': ['Column integrated divergence of water vapor mass flux', 'kg m-1s-1', 'CDWFMF'], '161': ['Column integrated divergence of cloud liquid water mass flux', 'kg m-1s-1', 'CDCLWMF'], '162': ['Column integrated divergence of cloud ice mass flux', 'kg m-1s-1', 'CDCIMF'], '163': ['Column integrated divergence of rain mass flux', 'kg m-1s-1', 'CDRMF'], '164': ['Column integrated divergence of snow mass flux', 'kg m-1s-1', 'CDSMF'], '165': ['Column integrated divergence of total water mass flux', 'kg m-1s-1', 'CDTWMF'], '166': ['Column integrated water vapor flux', 'kg m-1s-1', 'CWVF'], '167': ['Total column supercooled liquid water', 'kg m-2', 'TCSLW'], '168': ['Saturation specific humidity with respect to water', 'kg m-3', 'SSPFHW'], '169': ['Total column integrated saturation specific humidity with respect to water', 'kg m-2', 'TCISSPFHW'], '170': ['Mean Mass Diameter of Hail (see Note 10)', 'm', 'MEANHAIL'], '171': ['Estimated Maximum Diameter of Hail', 'm', 'MAXHAIL'], '172-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Categorical Rain', 'Code table 4.222', 'CRAIN'], '193': ['Categorical Freezing Rain', 'Code table 4.222', 'CFRZR'], '194': ['Categorical Ice Pellets', 'Code table 4.222', 'CICEP'], '195': ['Categorical Snow', 'Code table 4.222', 'CSNOW'], '196': ['Convective Precipitation Rate', 'kg m-2 s-1', 'CPRAT'], '197': ['Horizontal Moisture Divergence', 'kg kg-1 s-1', 'MDIV'], '198': ['Minimum Relative Humidity', '%', 'MINRH'], '199': ['Potential Evaporation', 'kg m-2', 'PEVAP'], '200': ['Potential Evaporation Rate', 'W m-2', 'PEVPR'], '201': ['Snow Cover', '%', 'SNOWC'], '202': ['Rain Fraction of Total Liquid Water', 'non-dim', 'FRAIN'], '203': ['Rime Factor', 'non-dim', 'RIME'], '204': ['Total Column Integrated Rain', 'kg m-2', 'TCOLR'], '205': ['Total Column Integrated Snow', 'kg m-2', 'TCOLS'], '206': ['Total Icing Potential Diagnostic', 'non-dim', 'TIPD'], '207': ['Number concentration for ice particles', 'non-dim', 'NCIP'], '208': ['Snow temperature', 'K', 'SNOT'], '209': ['Total column integrated supercooled liquid water', 'kg m-2', 'TCLSW'], '210': ['Total column integrated melting ice', 'kg m-2', 'TCOLM'], '211': ['Evaporation - Precipitation', 'cm/day', 'EMNP'], '212': ['Sublimation (evaporation from snow)', 'W m-2', 'SBSNO'], '213': ['Deep Convective Moistening Rate', 'kg kg-1 s-1', 'CNVMR'], '214': ['Shallow Convective Moistening Rate', 'kg kg-1 s-1', 'SHAMR'], '215': ['Vertical Diffusion Moistening Rate', 'kg kg-1 s-1', 'VDFMR'], '216': ['Condensation Pressure of Parcali Lifted From Indicate Surface', 'Pa', 'CONDP'], '217': ['Large-scale moistening rate', 'kg kg-1 s-1', 'LRGMR'], '218': ['Specific humidity at top of viscous sublayer', 'kg kg-1', 'QZ0'], '219': ['Maximum specific humidity at 2m', 'kg kg-1', 'QMAX'], '220': ['Minimum specific humidity at 2m', 'kg kg-1', 'QMIN'], '221': ['Liquid precipitation (Rainfall)', 'kg m-2', 'ARAIN'], '222': ['Snow temperature, depth average', 'K', 'SNOWT'], '223': ['Total precipitation (nearest grid point)', 'kg m-2', 'APCPN'], '224': ['Convective precipitation (nearest grid point)', 'kg m-2', 'ACPCPN'], '225': ['Freezing Rain', 'kg m-2', 'FRZR'], '226': ['Predominant Weather', 'Numeric', 'PWTHER'], '227': ['Frozen Rain', 'kg m-2', 'FROZR'], '228': ['Flat Ice Accumulation (FRAM)', 'kg m-2', 'FICEAC'], '229': ['Line Ice Accumulation (FRAM)', 'kg m-2', 'LICEAC'], '230': ['Sleet Accumulation', 'kg m-2', 'SLACC'], '231': ['Precipitation Potential Index', '%', 'PPINDX'], '232': ['Probability Cloud Ice Present', '%', 'PROBCIP'], '233': ['Snow Liquid Ratio', 'kg kg-1', 'SNOWLR'], '234': ['Precipitation Duration', 'hour', 'PCPDUR'], '235': ['Cloud Liquid Mixing Ratio', 'kg kg-1', 'CLLMR'], '236': ['Hail Accumulation', 'm', 'HAILAC'], '237': ['Total Column Integrated Precipitation', 'kg m-2', 'TCOLP'], '238': ['Hourly Maximum of 1-minute Average Precipitation Rate', 'kg m-2 s-1', 'PRATE1MIN'], '239': ['Hourly Maximum of 5-minute Average Precipitation Rate', 'kg m-2 s-1', 'PRATE5MIN'], '240': ['Hourly Maximum of 10-minute Average Precipitation Rate', 'kg m-2 s-1', 'PRATE10MIN'], '241': ['Total Snow', 'kg m-2', 'TSNOW'], '242': ['Relative Humidity with Respect to Precipitable Water', '%', 'RHPW'], '245': ['Hourly Maximum of Column Vertical Integrated Graupel on Entire Atmosphere', 'kg m-2', 'MAXVIG'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_2 = {'0': ['Wind Direction (from which blowing)', '°', 'WDIR'], '1': ['Wind Speed', 'm s-1', 'WIND'], '2': ['U-Component of Wind', 'm s-1', 'UGRD'], '3': ['V-Component of Wind', 'm s-1', 'VGRD'], '4': ['Stream Function', 'm2 s-1', 'STRM'], '5': ['Velocity Potential', 'm2 s-1', 'VPOT'], '6': ['Montgomery Stream Function', 'm2 s-2', 'MNTSF'], '7': ['σ Coordinate Vertical Velocity', 's-1', 'SGCVV'], '8': ['Vertical Velocity (Pressure)', 'Pa s-1', 'VVEL'], '9': ['Vertical Velocity (Geometric)', 'm s-1', 'DZDT'], '10': ['Absolute Vorticity', 's-1', 'ABSV'], '11': ['Absolute Divergence', 's-1', 'ABSD'], '12': ['Relative Vorticity', 's-1', 'RELV'], '13': ['Relative Divergence', 's-1', 'RELD'], '14': ['Potential Vorticity', 'K m2 kg-1 s-1', 'PVORT'], '15': ['Vertical U-Component Shear', 's-1', 'VUCSH'], '16': ['Vertical V-Component Shear', 's-1', 'VVCSH'], '17': ['Momentum Flux, U-Component', 'N m-2', 'UFLX'], '18': ['Momentum Flux, V-Component', 'N m-2', 'VFLX'], '19': ['Wind Mixing Energy', 'J', 'WMIXE'], '20': ['Boundary Layer Dissipation', 'W m-2', 'BLYDP'], '21': ['Maximum Wind Speed', 'm s-1', 'MAXGUST'], '22': ['Wind Speed (Gust)', 'm s-1', 'GUST'], '23': ['U-Component of Wind (Gust)', 'm s-1', 'UGUST'], '24': ['V-Component of Wind (Gust)', 'm s-1', 'VGUST'], '25': ['Vertical Speed Shear', 's-1', 'VWSH'], '26': ['Horizontal Momentum Flux', 'N m-2', 'MFLX'], '27': ['U-Component Storm Motion', 'm s-1', 'USTM'], '28': ['V-Component Storm Motion', 'm s-1', 'VSTM'], '29': ['Drag Coefficient', 'Numeric', 'CD'], '30': ['Frictional Velocity', 'm s-1', 'FRICV'], '31': ['Turbulent Diffusion Coefficient for Momentum', 'm2 s-1', 'TDCMOM'], '32': ['η Coordinate Vertical Velocity', 's-1', 'ETACVV'], '33': ['Wind Fetch', 'm', 'WINDF'], '34': ['Normal Wind Component', 'm s-1', 'NWIND'], '35': ['Tangential Wind Component', 'm s-1', 'TWIND'], '36': ['Amplitude Function for Rossby Wave Envelope for Meridional Wind', 'm s-1', 'AFRWE'], '37': ['Northward Turbulent Surface Stress (see Notes 4 and 7)', 'N m-2 s', 'NTSS'], '38': ['Eastward Turbulent Surface Stress (see Notes 4 and 7)', 'N m-2 s', 'ETSS'], '39': ['Eastward Wind Tendency Due to Parameterizations', 'm s-2', 'EWTPARM'], '40': ['Northward Wind Tendency Due to Parameterizations', 'm s-2', 'NWTPARM'], '41': ['U-Component of Geostrophic Wind', 'm s-1', 'UGWIND'], '42': ['V-Component of Geostrophic Wind', 'm s-1', 'VGWIND'], '43': ['Geostrophic Wind Direction', '°', 'GEOWD'], '44': ['Geostrophic Wind Speed', 'm s-1', 'GEOWS'], '45': ['Unbalanced Component of Divergence', 's-1', 'UNDIV'], '46': ['Vorticity Advection', 's-2', 'VORTADV'], '47': ['Surface roughness for heat', 'm', 'SFRHEAT'], '48': ['Surface roughness for moisture', 'm', 'SFRMOIST'], '49': ['Wind stress', 'N m-2', 'WINDSTR'], '50': ['Eastward wind stress', 'N m-2', 'EWINDSTR'], '51': ['Northward wind stress', 'N m-2', 'NWINDSTR'], '52': ['U-component of wind stress', 'N m-2', 'UWINDSTR'], '53': ['V-component of wind stress', 'N m-2', 'VWINDSTR'], '54': ['Natural logarithm of surface roughness length for heat', 'm', 'NLSRLH'], '55': ['Natural logarithm of surface roughness length for moisture', 'm', 'NLSRLM'], '56': ['U-component of neutral wind', 'm s-1', 'UNWIND'], '57': ['V-component of neutral wind', 'm s-1', 'VNWIND'], '58': ['Magnitude of turbulent surface stress', 'N m-2', 'TSFCSTR'], '59': ['Vertical divergence', 's-1', 'VDIV'], '60': ['Drag thermal coefficient', 'Numeric', 'DTC'], '61': ['Drag evaporation coefficient', 'Numeric', 'DEC'], '62': ['Eastward turbulent surface stress', 'N m-2', 'EASTTSS'], '63': ['Northward turbulent surface stress', 'N m-2', 'NRTHTSS'], '64': ['Eastward turbulent surface stress due to orographic form drag', 'N m-2', 'EASTTSSOD'], '65': ['Northward turbulent surface stress due to orographic form drag', 'N m-2', 'NRTHTSSOD'], '66': ['Eastward turbulent surface stress due to surface roughness', 'N m-2', 'EASTTSSSR'], '67': ['Northward turbulent surface stress due to surface roughness', 'N m-2', 'NRTHTSSSR'], '68': ['Convective Gust', 'm s-1', 'CNVGUST'], '69': ['Turbulent Gust', 'm s-1', 'TURBGUST'], '70-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Vertical Speed Shear', 's-1', 'VWSH'], '193': ['Horizontal Momentum Flux', 'N m-2', 'MFLX'], '194': ['U-Component Storm Motion', 'm s-1', 'USTM'], '195': ['V-Component Storm Motion', 'm s-1', 'VSTM'], '196': ['Drag Coefficient', 'non-dim', 'CD'], '197': ['Frictional Velocity', 'm s-1', 'FRICV'], '198': ['Latitude of U Wind Component of Velocity', 'deg', 'LAUV'], '199': ['Longitude of U Wind Component of Velocity', 'deg', 'LOUV'], '200': ['Latitude of V Wind Component of Velocity', 'deg', 'LAVV'], '201': ['Longitude of V Wind Component of Velocity', 'deg', 'LOVV'], '202': ['Latitude of Presure Point', 'deg', 'LAPP'], '203': ['Longitude of Presure Point', 'deg', 'LOPP'], '204': ['Vertical Eddy Diffusivity Heat Exchange', 'm2 s-1', 'VEDH'], '205': ['Covariance between Meridional and Zonal Components of the Wind', 'm2 s-2', 'COVMZ'], '206': ['Covariance between Temperature and Zonal Components of the Wind', 'K*m s-1', 'COVTZ'], '207': ['Covariance between Temperature and Meridional Components of the Wind', 'K*m s-1', 'COVTM'], '208': ['Vertical Diffusion Zonal Acceleration', 'm s-2', 'VDFUA'], '209': ['Vertical Diffusion Meridional Acceleration', 'm s-2', 'VDFVA'], '210': ['Gravity wave drag zonal acceleration', 'm s-2', 'GWDU'], '211': ['Gravity wave drag meridional acceleration', 'm s-2', 'GWDV'], '212': ['Convective zonal momentum mixing acceleration', 'm s-2', 'CNVU'], '213': ['Convective meridional momentum mixing acceleration', 'm s-2', 'CNVV'], '214': ['Tendency of vertical velocity', 'm s-2', 'WTEND'], '215': ['ω (Dp/Dt) divided by density', 'K', 'OMGALF'], '216': ['Convective Gravity wave drag zonal acceleration', 'm s-2', 'CNGWDU'], '217': ['Convective Gravity wave drag meridional acceleration', 'm s-2', 'CNGWDV'], '218': ['Velocity Point Model Surface', 'unknown', 'LMV'], '219': ['Potential Vorticity (Mass-Weighted)', '1/s/m', 'PVMWW'], '220': ['Hourly Maximum of Upward Vertical Velocity', 'm s-1', 'MAXUVV'], '221': ['Hourly Maximum of Downward Vertical Velocity', 'm s-1', 'MAXDVV'], '222': ['U Component of Hourly Maximum 10m Wind Speed', 'm s-1', 'MAXUW'], '223': ['V Component of Hourly Maximum 10m Wind Speed', 'm s-1', 'MAXVW'], '224': ['Ventilation Rate', 'm2 s-1', 'VRATE'], '225': ['Transport Wind Speed', 'm s-1', 'TRWSPD'], '226': ['Transport Wind Direction', 'Deg', 'TRWDIR'], '227': ['Earliest Reasonable Arrival Time (10% exceedance)', 's', 'TOA10'], '228': ['Most Likely Arrival Time (50% exceedance)', 's', 'TOA50'], '229': ['Most Likely Departure Time (50% exceedance)', 's', 'TOD50'], '230': ['Latest Reasonable Departure Time (90% exceedance)', 's', 'TOD90'], '231': ['Tropical Wind Direction', '°', 'TPWDIR'], '232': ['Tropical Wind Speed', 'm s-1', 'TPWSPD'], '233': ['Inflow Based (ESFC) to 50% EL Shear Magnitude', 'kt', 'ESHR'], '234': ['U Component Inflow Based to 50% EL Shear Vector', 'kt', 'UESH'], '235': ['V Component Inflow Based to 50% EL Shear Vector', 'kt', 'VESH'], '236': ['U Component Bunkers Effective Right Motion', 'kt', 'UEID'], '237': ['V Component Bunkers Effective Right Motion', 'kt', 'VEID'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_3 = {'0': ['Pressure', 'Pa', 'PRES'], '1': ['Pressure Reduced to MSL', 'Pa', 'PRMSL'], '2': ['Pressure Tendency', 'Pa s-1', 'PTEND'], '3': ['ICAO Standard Atmosphere Reference Height', 'm', 'ICAHT'], '4': ['Geopotential', 'm2 s-2', 'GP'], '5': ['Geopotential Height', 'gpm', 'HGT'], '6': ['Geometric Height', 'm', 'DIST'], '7': ['Standard Deviation of Height', 'm', 'HSTDV'], '8': ['Pressure Anomaly', 'Pa', 'PRESA'], '9': ['Geopotential Height Anomaly', 'gpm', 'GPA'], '10': ['Density', 'kg m-3', 'DEN'], '11': ['Altimeter Setting', 'Pa', 'ALTS'], '12': ['Thickness', 'm', 'THICK'], '13': ['Pressure Altitude', 'm', 'PRESALT'], '14': ['Density Altitude', 'm', 'DENALT'], '15': ['5-Wave Geopotential Height', 'gpm', '5WAVH'], '16': ['Zonal Flux of Gravity Wave Stress', 'N m-2', 'U-GWD'], '17': ['Meridional Flux of Gravity Wave Stress', 'N m-2', 'V-GWD'], '18': ['Planetary Boundary Layer Height', 'm', 'HPBL'], '19': ['5-Wave Geopotential Height Anomaly', 'gpm', '5WAVA'], '20': ['Standard Deviation of Subgrid Scale Orography', 'm', 'SDSGSO'], '21': ['Angle of Subgrid Scale Orography', 'rad', 'AOSGSO'], '22': ['Slope of Subgrid Scale Orography', 'Numeric', 'SSGSO'], '23': ['Gravity Wave Dissipation', 'W m-2', 'GWD'], '24': ['Anisotropy of Subgrid Scale Orography', 'Numeric', 'ASGSO'], '25': ['Natural Logarithm of Pressure in Pa', 'Numeric', 'NLPRES'], '26': ['Exner Pressure', 'Numeric', 'EXPRES'], '27': ['Updraught Mass Flux', 'kg m-2 s-1', 'UMFLX'], '28': ['Downdraught Mass Flux', 'kg m-2 s-1', 'DMFLX'], '29': ['Updraught Detrainment Rate', 'kg m-3 s-1', 'UDRATE'], '30': ['Downdraught Detrainment Rate', 'kg m-3 s-1', 'DDRATE'], '31': ['Unbalanced Component of Logarithm of Surface Pressure', '-', 'UCLSPRS'], '32': ['Saturation water vapour pressure', 'Pa', 'SWATERVP'], '33': ['Geometric altitude above mean sea level', 'm', 'GAMSL'], '34': ['Geometric height above ground level', 'm', 'GHAGRD'], '35': ['Column integrated divergence of total mass flux', 'kg m-2 s-1', 'CDTMF'], '36': ['Column integrated eastward total mass flux', 'kg m-2 s-1', 'CETMF'], '37': ['Column integrated northward total mass flux', 'kg m-2 s-1', 'CNTMF'], '38': ['Standard deviation of filtered subgrid orography', 'm', 'SDFSO'], '39': ['Column integrated mass of atmosphere', 'kg m-2 s-1', 'CMATMOS'], '40': ['Column integrated eastward geopotential flux', 'W m-1', 'CEGFLUX'], '41': ['Column integrated northward geopotential flux', 'W m-1', 'CNGFLUX'], '42': ['Column integrated divergence of water geopotential flux', 'W m-2', 'CDWGFLUX'], '43': ['Column integrated divergence of geopotential flux', 'W m-2', 'CDGFLUX'], '44': ['Height of zero-degree wet-bulb temperature', 'm', 'HWBT'], '45': ['Height of one-degree wet-bulb temperature', 'm', 'WOBT'], '46': ['Pressure departure from hydrostatic state', 'Pa', 'PRESDHS'], '47-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['MSLP (Eta model reduction)', 'Pa', 'MSLET'], '193': ['5-Wave Geopotential Height', 'gpm', '5WAVH'], '194': ['Zonal Flux of Gravity Wave Stress', 'N m-2', 'U-GWD'], '195': ['Meridional Flux of Gravity Wave Stress', 'N m-2', 'V-GWD'], '196': ['Planetary Boundary Layer Height', 'm', 'HPBL'], '197': ['5-Wave Geopotential Height Anomaly', 'gpm', '5WAVA'], '198': ['MSLP (MAPS System Reduction)', 'Pa', 'MSLMA'], '199': ['3-hr pressure tendency (Std. Atmos. Reduction)', 'Pa s-1', 'TSLSA'], '200': ['Pressure of level from which parcel was lifted', 'Pa', 'PLPL'], '201': ['X-Gradient of Log Pressure', 'm-1', 'LPSX'], '202': ['Y-Gradient of Log Pressure', 'm-1', 'LPSY'], '203': ['X-Gradient of Height', 'm-1', 'HGTX'], '204': ['Y-Gradient of Height', 'm-1', 'HGTY'], '205': ['Layer Thickness', 'm', 'LAYTH'], '206': ['Natural Log of Surface Pressure', 'ln (kPa)', 'NLGSP'], '207': ['Convective updraft mass flux', 'kg m-2 s-1', 'CNVUMF'], '208': ['Convective downdraft mass flux', 'kg m-2 s-1', 'CNVDMF'], '209': ['Convective detrainment mass flux', 'kg m-2 s-1', 'CNVDEMF'], '210': ['Mass Point Model Surface', 'unknown', 'LMH'], '211': ['Geopotential Height (nearest grid point)', 'gpm', 'HGTN'], '212': ['Pressure (nearest grid point)', 'Pa', 'PRESN'], '213': ['Orographic Convexity', 'unknown', 'ORCONV'], '214': ['Orographic Asymmetry, W Component', 'unknown', 'ORASW'], '215': ['Orographic Asymmetry, S Component', 'unknown', 'ORASS'], '216': ['Orographic Asymmetry, SW Component', 'unknown', 'ORASSW'], '217': ['Orographic Asymmetry, NW Component', 'unknown', 'ORASNW'], '218': ['Orographic Length Scale, W Component', 'unknown', 'ORLSW'], '219': ['Orographic Length Scale, S Component', 'unknown', 'ORLSS'], '220': ['Orographic Length Scale, SW Component', 'unknown', 'ORLSSW'], '221': ['Orographic Length Scale, NW Component', 'unknown', 'ORLSNW'], '222': ['Effective Surface Height', 'm', 'EFSH'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_4 = {'0': ['Net Shortwave Radiation Flux (Surface)', 'W m-2', 'NSWRS'], '1': ['Net Shortwave Radiation Flux (Top of Atmosphere)', 'W m-2', 'NSWRT'], '2': ['Shortwave Radiation Flux', 'W m-2', 'SWAVR'], '3': ['Global Radiation Flux', 'W m-2', 'GRAD'], '4': ['Brightness Temperature', 'K', 'BRTMP'], '5': ['Radiance (with respect to wavenumber)', 'W m-1 sr-1', 'LWRAD'], '6': ['Radiance (with respect to wavelength)', 'W m-3 sr-1', 'SWRAD'], '7': ['Downward Shortwave Radiation Flux', 'W m-2', 'DSWRF'], '8': ['Upward Shortwave Radiation Flux', 'W m-2', 'USWRF'], '9': ['Net Shortwave Radiation Flux', 'W m-2', 'NSWRF'], '10': ['Photosynthetically Active Radiation', 'W m-2', 'PHOTAR'], '11': ['Net Shortwave Radiation Flux, Clear Sky', 'W m-2', 'NSWRFCS'], '12': ['Downward UV Radiation', 'W m-2', 'DWUVR'], '13': ['Direct Shortwave Radiation Flux', 'W m-2', 'DSWRFLX'], '14': ['Diffuse Shortwave Radiation Flux', 'W m-2', 'DIFSWRF'], '15': ['Upward UV radiation emitted/reflected from the Earths surface', 'W m-2', 'UVVEARTH'], '16-49': ['Reserved', 'unknown', 'unknown'], '50': ['UV Index (Under Clear Sky)', 'Numeric', 'UVIUCS'], '51': ['UV Index', 'Numeric', 'UVI'], '52': ['Downward Shortwave Radiation Flux, Clear Sky', 'W m-2', 'DSWRFCS'], '53': ['Upward Shortwave Radiation Flux, Clear Sky', 'W m-2', 'USWRFCS'], '54': ['Direct normal shortwave radiation flux,', 'W m-2', 'DNSWRFLX'], '55': ['UV visible albedo for diffuse radiation', '%', 'UVALBDIF'], '56': ['UV visible albedo for direct radiation', '%', 'UVALBDIR'], '57': ['UV visible albedo for direct radiation, geometric component', '%', 'UBALBDIRG'], '58': ['UV visible albedo for direct radiation, isotropic component', '%', 'UVALBDIRI'], '59': ['UV visible albedo for direct radiation, volumetric component', '%', 'UVBDIRV'], '60': ['Photosynthetically active radiation flux, clear sky', 'W m-2', 'PHOARFCS'], '61': ['Direct shortwave radiation flux, clear sky', 'W m-2', 'DSWRFLXCS'], '62': ['Direct Normal Shortwave Radiation Flux, Clear Sky', 'W m-2', 'DNSWRFLXCS'], '63': ['Diffuse Shortwave Radiation Flux, Clear Sky', 'W m-2', 'DFSWRFLXCS'], '64-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Downward Shortwave Radiation Flux', 'W m-2', 'DSWRF'], '193': ['Upward Shortwave Radiation Flux', 'W m-2', 'USWRF'], '194': ['UV-B Downward Solar Flux', 'W m-2', 'DUVB'], '195': ['Clear sky UV-B Downward Solar Flux', 'W m-2', 'CDUVB'], '196': ['Clear Sky Downward Solar Flux', 'W m-2', 'CSDSF'], '197': ['Solar Radiative Heating Rate', 'K s-1', 'SWHR'], '198': ['Clear Sky Upward Solar Flux', 'W m-2', 'CSUSF'], '199': ['Cloud Forcing Net Solar Flux', 'W m-2', 'CFNSF'], '200': ['Visible Beam Downward Solar Flux', 'W m-2', 'VBDSF'], '201': ['Visible Diffuse Downward Solar Flux', 'W m-2', 'VDDSF'], '202': ['Near IR Beam Downward Solar Flux', 'W m-2', 'NBDSF'], '203': ['Near IR Diffuse Downward Solar Flux', 'W m-2', 'NDDSF'], '204': ['Downward Total Radiation Flux', 'W m-2', 'DTRF'], '205': ['Upward Total Radiation Flux', 'W m-2', 'UTRF'], '206': ['Diffuse Shortwave Radiation Flux, Clear Sky', 'W m-2', 'DFSWRFLXCS'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_5 = {'0': ['Net Longwave Radiation Flux (Surface)', 'W m-2', 'NLWRS'], '1': ['Net Longwave Radiation Flux (Top of Atmosphere)', 'W m-2', 'NLWRT'], '2': ['Longwave Radiation Flux', 'W m-2', 'LWAVR'], '3': ['Downward Longwave Radiation Flux', 'W m-2', 'DLWRF'], '4': ['Upward Longwave Radiation Flux', 'W m-2', 'ULWRF'], '5': ['Net Longwave Radiation Flux', 'W m-2', 'NLWRF'], '6': ['Net Longwave Radiation Flux, Clear Sky', 'W m-2', 'NLWRCS'], '7': ['Brightness Temperature', 'K', 'BRTEMP'], '8': ['Downward Longwave Radiation Flux, Clear Sky', 'W m-2', 'DLWRFCS'], '9': ['Near IR albedo for diffuse radiation', '%', 'NIRALBDIF'], '10': ['Near IR albedo for direct radiation', '%', 'NIRALBDIR'], '11': ['Near IR albedo for direct radiation, geometric component', '%', 'NIRALBDIRG'], '12': ['Near IR albedo for direct radiation, isotropic component', '%', 'NIRALBDIRI'], '13': ['Near IR albedo for direct radiation, volumetric component', '%', 'NIRALBDIRV'], '14-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Downward Longwave Radiation Flux', 'W m-2', 'DLWRF'], '193': ['Upward Longwave Radiation Flux', 'W m-2', 'ULWRF'], '194': ['Longwave Radiative Heating Rate', 'K s-1', 'LWHR'], '195': ['Clear Sky Upward Longwave Flux', 'W m-2', 'CSULF'], '196': ['Clear Sky Downward Longwave Flux', 'W m-2', 'CSDLF'], '197': ['Cloud Forcing Net Longwave Flux', 'W m-2', 'CFNLF'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_6 = {'0': ['Cloud Ice', 'kg m-2', 'CICE'], '1': ['Total Cloud Cover', '%', 'TCDC'], '2': ['Convective Cloud Cover', '%', 'CDCON'], '3': ['Low Cloud Cover', '%', 'LCDC'], '4': ['Medium Cloud Cover', '%', 'MCDC'], '5': ['High Cloud Cover', '%', 'HCDC'], '6': ['Cloud Water', 'kg m-2', 'CWAT'], '7': ['Cloud Amount', '%', 'CDCA'], '8': ['Cloud Type', 'See Table 4.203', 'CDCT'], '9': ['Thunderstorm Maximum Tops', 'm', 'TMAXT'], '10': ['Thunderstorm Coverage', 'See Table 4.204', 'THUNC'], '11': ['Cloud Base', 'm', 'CDCB'], '12': ['Cloud Top', 'm', 'CDCTOP'], '13': ['Ceiling', 'm', 'CEIL'], '14': ['Non-Convective Cloud Cover', '%', 'CDLYR'], '15': ['Cloud Work Function', 'J kg-1', 'CWORK'], '16': ['Convective Cloud Efficiency', 'Proportion', 'CUEFI'], '17': ['Total Condensate', 'kg kg-1', 'TCONDO'], '18': ['Total Column Integrated Cloud Water', 'kg m-2', 'TCOLWO'], '19': ['Total Column Integrated Cloud Ice', 'kg m-2', 'TCOLIO'], '20': ['Total Column Integrated Condensate', 'kg m-2', 'TCOLC'], '21': ['Ice fraction of total condensate', 'Proportion', 'FICE'], '22': ['Cloud Cover', '%', 'CDCC'], '23': ['Cloud Ice Mixing Ratio', 'kg kg-1', 'CDCIMR'], '24': ['Sunshine', 'Numeric', 'SUNS'], '25': ['Horizontal Extent of Cumulonimbus (CB)', '%', 'CBHE'], '26': ['Height of Convective Cloud Base', 'm', 'HCONCB'], '27': ['Height of Convective Cloud Top', 'm', 'HCONCT'], '28': ['Number Concentration of Cloud Droplets', 'kg-1', 'NCONCD'], '29': ['Number Concentration of Cloud Ice', 'kg-1', 'NCCICE'], '30': ['Number Density of Cloud Droplets', 'm-3', 'NDENCD'], '31': ['Number Density of Cloud Ice', 'm-3', 'NDCICE'], '32': ['Fraction of Cloud Cover', 'Numeric', 'FRACCC'], '33': ['Sunshine Duration', 's', 'SUNSD'], '34': ['Surface Long Wave Effective Total Cloudiness', 'Numeric', 'SLWTC'], '35': ['Surface Short Wave Effective Total Cloudiness', 'Numeric', 'SSWTC'], '36': ['Fraction of Stratiform Precipitation Cover', 'Proportion', 'FSTRPC'], '37': ['Fraction of Convective Precipitation Cover', 'Proportion', 'FCONPC'], '38': ['Mass Density of Cloud Droplets', 'kg m-3', 'MASSDCD'], '39': ['Mass Density of Cloud Ice', 'kg m-3', 'MASSDCI'], '40': ['Mass Density of Convective Cloud Water Droplets', 'kg m-3', 'MDCCWD'], '41-46': ['Reserved', 'unknown', 'unknown'], '47': ['Volume Fraction of Cloud Water Droplets', 'Numeric', 'VFRCWD'], '48': ['Volume Fraction of Cloud Ice Particles', 'Numeric', 'VFRCICE'], '49': ['Volume Fraction of Cloud (Ice and/or Water)', 'Numeric', 'VFRCIW'], '50': ['Fog', '%', 'FOG'], '51': ['Sunshine Duration Fraction', 'Proportion', 'SUNFRAC'], '52-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Non-Convective Cloud Cover', '%', 'CDLYR'], '193': ['Cloud Work Function', 'J kg-1', 'CWORK'], '194': ['Convective Cloud Efficiency', 'non-dim', 'CUEFI'], '195': ['Total Condensate', 'kg kg-1', 'TCOND'], '196': ['Total Column Integrated Cloud Water', 'kg m-2', 'TCOLW'], '197': ['Total Column Integrated Cloud Ice', 'kg m-2', 'TCOLI'], '198': ['Total Column Integrated Condensate', 'kg m-2', 'TCOLC'], '199': ['Ice fraction of total condensate', 'non-dim', 'FICE'], '200': ['Convective Cloud Mass Flux', 'Pa s-1', 'MFLUX'], '201': ['Sunshine Duration', 's', 'SUNSD'], '202': ['Fog (LWC)', 'g kg-1', 'FOGLWC'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_7 = {'0': ['Parcel Lifted Index (to 500 hPa)', 'K', 'PLI'], '1': ['Best Lifted Index (to 500 hPa)', 'K', 'BLI'], '2': ['K Index', 'K', 'KX'], '3': ['KO Index', 'K', 'KOX'], '4': ['Total Totals Index', 'K', 'TOTALX'], '5': ['Sweat Index', 'Numeric', 'SX'], '6': ['Convective Available Potential Energy', 'J kg-1', 'CAPE'], '7': ['Convective Inhibition', 'J kg-1', 'CIN'], '8': ['Storm Relative Helicity', 'm2 s-2', 'HLCY'], '9': ['Energy Helicity Index', 'Numeric', 'EHLX'], '10': ['Surface Lifted Index', 'K', 'LFTX'], '11': ['Best (4 layer) Lifted Index', 'K', '4LFTX'], '12': ['Richardson Number', 'Numeric', 'RI'], '13': ['Showalter Index', 'K', 'SHWINX'], '14': ['Reserved', 'unknown', 'unknown'], '15': ['Updraft Helicity', 'm2 s-2', 'UPHL'], '16': ['Bulk Richardson Number', 'Numeric', 'BLKRN'], '17': ['Gradient Richardson Number', 'Numeric', 'GRDRN'], '18': ['Flux Richardson Number', 'Numeric', 'FLXRN'], '19': ['Convective Available Potential Energy - Shear', 'm2 s-2', 'CONAPES'], '20': ['Thunderstorm Intensity Index', 'See Table 4.246', 'TIIDEX'], '21': ['Storm Severity Index', 'Numeric', 'SSI'], '22': ['Reciprocal Obukhov Length', 'm-1', 'RMOL'], '23-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Surface Lifted Index', 'K', 'LFTX'], '193': ['Best (4 layer) Lifted Index', 'K', '4LFTX'], '194': ['Richardson Number', 'Numeric', 'RI'], '195': ['Convective Weather Detection Index', 'unknown', 'CWDI'], '196': ['Ultra Violet Index', 'W m-2', 'UVI'], '197': ['Updraft Helicity', 'm2 s-2', 'UPHL'], '198': ['Leaf Area Index', 'Numeric', 'LAI'], '199': ['Hourly Maximum of Updraft Helicity', 'm2 s-2', 'MXUPHL'], '200': ['Hourly Minimum of Updraft Helicity', 'm2 s-2', 'MNUPHL'], '201': ['Bourgoiun Negative Energy Layer (surface to freezing level)', 'J kg-1', 'BNEGELAY'], '202': ['Bourgoiun Positive Energy Layer (2k ft AGL to 400 hPa)', 'J kg-1', 'BPOSELAY'], '203': ['Downdraft CAPE', 'J kg-1', 'DCAPE'], '204': ['Effective Storm Relative Helicity', 'm2 s-2', 'EFHL'], '205': ['Enhanced Stretching Potential', 'Numeric', 'ESP'], '206': ['Critical Angle', 'Degree', 'CANGLE'], '207': ['Effective Surface Helicity', 'm2 s-2', 'E3KH'], '208': ['Significant Tornado Parameter with CIN - Effective Layer', 'numeric', 'STPC'], '209': ['Significant Hail Parameter', 'numeric', 'SIGH'], '210': ['Supercell Composite Parameter - Effective Layer', 'numeric', 'SCCP'], '211': ['Significant Tornado Parameter - Fixed Layer', 'numeric', 'SIGT'], '212': ['Mixed Layer (100 mb) Virtual LFC', 'numeric', 'MLFC'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_13 = {'0': ['Aerosol Type', 'See Table 4.205', 'AEROT'], '1-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Particulate matter (coarse)', 'µg m-3', 'PMTC'], '193': ['Particulate matter (fine)', 'µg m-3', 'PMTF'], '194': ['Particulate matter (fine)', 'log10 (µg m-3)', 'LPMTF'], '195': ['Integrated column particulate matter (fine)', 'log10 (µg m-3)', 'LIPMF'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_14 = {'0': ['Total Ozone', 'DU', 'TOZNE'], '1': ['Ozone Mixing Ratio', 'kg kg-1', 'O3MR'], '2': ['Total Column Integrated Ozone', 'DU', 'TCIOZ'], '3-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Ozone Mixing Ratio', 'kg kg-1', 'O3MR'], '193': ['Ozone Concentration', 'ppb', 'OZCON'], '194': ['Categorical Ozone Concentration', 'Non-Dim', 'OZCAT'], '195': ['Ozone Vertical Diffusion', 'kg kg-1 s-1', 'VDFOZ'], '196': ['Ozone Production', 'kg kg-1 s-1', 'POZ'], '197': ['Ozone Tendency', 'kg kg-1 s-1', 'TOZ'], '198': ['Ozone Production from Temperature Term', 'kg kg-1 s-1', 'POZT'], '199': ['Ozone Production from Column Ozone Term', 'kg kg-1 s-1', 'POZO'], '200': ['Ozone Daily Max from 1-hour Average', 'ppbV', 'OZMAX1'], '201': ['Ozone Daily Max from 8-hour Average', 'ppbV', 'OZMAX8'], '202': ['PM 2.5 Daily Max from 1-hour Average', 'μg m-3', 'PDMAX1'], '203': ['PM 2.5 Daily Max from 24-hour Average', 'μg m-3', 'PDMAX24'], '204': ['Acetaldehyde & Higher Aldehydes', 'ppbV', 'ALD2'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_15 = {'0': ['Base Spectrum Width', 'm s-1', 'BSWID'], '1': ['Base Reflectivity', 'dB', 'BREF'], '2': ['Base Radial Velocity', 'm s-1', 'BRVEL'], '3': ['Vertically-Integrated Liquid Water', 'kg m-2', 'VIL'], '4': ['Layer Maximum Base Reflectivity', 'dB', 'LMAXBR'], '5': ['Precipitation', 'kg m-2', 'PREC'], '6': ['Radar Spectra (1)', 'unknown', 'RDSP1'], '7': ['Radar Spectra (2)', 'unknown', 'RDSP2'], '8': ['Radar Spectra (3)', 'unknown', 'RDSP3'], '9': ['Reflectivity of Cloud Droplets', 'dB', 'RFCD'], '10': ['Reflectivity of Cloud Ice', 'dB', 'RFCI'], '11': ['Reflectivity of Snow', 'dB', 'RFSNOW'], '12': ['Reflectivity of Rain', 'dB', 'RFRAIN'], '13': ['Reflectivity of Graupel', 'dB', 'RFGRPL'], '14': ['Reflectivity of Hail', 'dB', 'RFHAIL'], '15': ['Hybrid Scan Reflectivity', 'dB', 'HSR'], '16': ['Hybrid Scan Reflectivity Height', 'm', 'HSRHT'], '17': ['Precipitation Rate', 'kg m-2 s-1', 'PRATERAD'], '18': ['Radar Data Quality Index', 'Proportion', 'RQI'], '19': ['Radar Data Quality Flag', 'See Table 4.106', 'RDQF'], '20': ['Layer Maximum Precipitation Rate', 'kg m-2 s-1', 'LMAXPRATE'], '21-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Vertically-Integrated Liquid Water', 'kg m-2', 'RADARVIL'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_16 = {'0': ['Equivalent radar reflectivity factor for rain', 'm m6 m-3', 'REFZR'], '1': ['Equivalent radar reflectivity factor for snow', 'm m6 m-3', 'REFZI'], '2': ['Equivalent radar reflectivity factor for parameterized convection', 'm m6 m-3', 'REFZC'], '3': ['Echo Top', 'm', 'RETOP'], '4': ['Reflectivity', 'dB', 'REFD'], '5': ['Composite reflectivity', 'dB', 'REFC'], '6': ['Precipitation Rate', 'kg m-2 s-1', 'PRATEFRAD'], '7': ['Layer Maximum Precipitation Rate', 'kg m-2 s-1', 'LMAXPRATEF'], '8': ['Layer Maximum Reflectivity', 'dB', 'LMAXREF'], '9-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Equivalent radar reflectivity factor for rain', 'm m6 m-3', 'REFZR'], '193': ['Equivalent radar reflectivity factor for snow', 'm m6 m-3', 'REFZI'], '194': ['Equivalent radar reflectivity factor for parameterized convection', 'm m6 m-3', 'REFZC'], '195': ['Reflectivity', 'dB', 'REFD'], '196': ['Composite reflectivity', 'dB', 'REFC'], '197': ['Echo Top', 'm', 'RETOP'], '198': ['Hourly Maximum of Simulated Reflectivity', 'dB', 'MAXREF'], '199': ['Hourly Maximum of Composite Reflectivity', 'dB', 'MAXREFC'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_17 = {'0': ['Lightning Strike Density', 'm-2 s-1', 'LTNGSD'], '1': ['Lightning Potential Index (LPI)', 'J kg-1', 'LTPINX'], '2': ['Cloud-to-Ground Lightning Flash Density', 'km-2 day-1', 'CDGDLTFD'], '3': ['Cloud-to-Cloud Lightning Flash Density', 'km-2 day-1', 'CDCDLTFD'], '4': ['Total Lightning Flash Density', 'km-2 day-1', 'TLGTFD'], '5': ['Subgrid-scale Lightning Potential Index', 'J kg-1', 'SLNGPIDX'], '6-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Lightning', 'non-dim', 'LTNG'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_18 = {'0': ['Air Concentration of Caesium 137', 'Bq m-3', 'ACCES'], '1': ['Air Concentration of Iodine 131', 'Bq m-3', 'ACIOD'], '2': ['Air Concentration of Radioactive Pollutant', 'Bq m-3', 'ACRADP'], '3': ['Ground Deposition of Caesium 137', 'Bq m-2', 'GDCES'], '4': ['Ground Deposition of Iodine 131', 'Bq m-2', 'GDIOD'], '5': ['Ground Deposition of Radioactive Pollutant', 'Bq m-2', 'GDRADP'], '6': ['Time Integrated Air Concentration of Cesium Pollutant', 'Bq s m-3', 'TIACCP'], '7': ['Time Integrated Air Concentration of Iodine Pollutant', 'Bq s m-3', 'TIACIP'], '8': ['Time Integrated Air Concentration of Radioactive Pollutant', 'Bq s m-3', 'TIACRP'], '9': ['Reserved', 'unknown', 'unknown'], '10': ['Air Concentration', 'Bq m-3', 'AIRCON'], '11': ['Wet Deposition', 'Bq m-2', 'WETDEP'], '12': ['Dry Deposition', 'Bq m-2', 'DRYDEP'], '13': ['Total Deposition (Wet + Dry)', 'Bq m-2', 'TOTLWD'], '14': ['Specific Activity Concentration', 'Bq kg-1', 'SACON'], '15': ['Maximum of Air Concentration in Layer', 'Bq m-3', 'MAXACON'], '16': ['Height of Maximum of Air Concentration', 'm', 'HMXACON'], '17': ['Column Integrated Air Concentration', 'Bq m-2', 'CIAIRC'], '18': ['Column Averaged Air Concentration in Layer', 'Bq m-3', 'CAACL'], '19': ['Deposition activity arrival', 's', 'DEPACTA'], '20': ['Deposition activity ended', 's', 'DEPACTE'], '21': ['Cloud activity arrival', 's', 'CLDACTA'], '22': ['Cloud activity ended', 's', 'CLDACTE'], '23': ['Effective dose rate', 'nSv h-1', 'EFFDOSER'], '24': ['Thyroid dose rate (adult)', 'nSv h-1', 'THYDOSER'], '25': ['Gamma dose rate (adult)', 'nSv h-1', 'GAMDOSER'], '26': ['Activity emission', 'Bq s-1', 'ACTEMM'], '27-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_19 = {'0': ['Visibility', 'm', 'VIS'], '1': ['Albedo', '%', 'ALBDO'], '2': ['Thunderstorm Probability', '%', 'TSTM'], '3': ['Mixed Layer Depth', 'm', 'MIXHT'], '4': ['Volcanic Ash', 'See Table 4.206', 'VOLASH'], '5': ['Icing Top', 'm', 'ICIT'], '6': ['Icing Base', 'm', 'ICIB'], '7': ['Icing', 'See Table 4.207', 'ICI'], '8': ['Turbulence Top', 'm', 'TURBT'], '9': ['Turbulence Base', 'm', 'TURBB'], '10': ['Turbulence', 'See Table 4.208', 'TURB'], '11': ['Turbulent Kinetic Energy', 'J kg-1', 'TKE'], '12': ['Planetary Boundary Layer Regime', 'See Table 4.209', 'PBLREG'], '13': ['Contrail Intensity', 'See Table 4.210', 'CONTI'], '14': ['Contrail Engine Type', 'See Table 4.211', 'CONTET'], '15': ['Contrail Top', 'm', 'CONTT'], '16': ['Contrail Base', 'm', 'CONTB'], '17': ['Maximum Snow Albedo', '%', 'MXSALB'], '18': ['Snow-Free Albedo', '%', 'SNFALB'], '19': ['Snow Albedo', '%', 'SALBD'], '20': ['Icing', '%', 'ICIP'], '21': ['In-Cloud Turbulence', '%', 'CTP'], '22': ['Clear Air Turbulence (CAT)', '%', 'CAT'], '23': ['Supercooled Large Droplet Probability', '%', 'SLDP'], '24': ['Convective Turbulent Kinetic Energy', 'J kg-1', 'CONTKE'], '25': ['Weather', 'See Table 4.225', 'WIWW'], '26': ['Convective Outlook', 'See Table 4.224', 'CONVO'], '27': ['Icing Scenario', 'See Table 4.227', 'ICESC'], '28': ['Mountain Wave Turbulence (Eddy Dissipation Rate)', 'm2/3 s-1', 'MWTURB'], '29': ['Clear Air Turbulence (CAT) (Eddy Dissipation Rate)', 'm2/3 s-1', 'CATEDR'], '30': ['Eddy Dissipation Parameter', 'm2/3 s-1', 'EDPARM'], '31': ['Maximum of Eddy Dissipation Parameter in Layer', 'm2/3 s-1', 'MXEDPRM'], '32': ['Highest Freezing Level', 'm', 'HIFREL'], '33': ['Visibility Through Liquid Fog', 'm', 'VISLFOG'], '34': ['Visibility Through Ice Fog', 'm', 'VISIFOG'], '35': ['Visibility Through Blowing Snow', 'm', 'VISBSN'], '36': ['Presence of Snow Squalls', 'See Table 4.222', 'PSNOWS'], '37': ['Icing Severity', 'See Table 4.228', 'ICESEV'], '38': ['Sky transparency index', 'See Table 4.214', 'SKYIDX'], '39': ['Seeing index', 'See Table 4.214', 'SEEINDEX'], '40': ['Snow level', 'm', 'SNOWLVL'], '41': ['Duct base height', 'm', 'DBHEIGHT'], '42': ['Trapping layer base height', 'm', 'TLBHEIGHT'], '43': ['Trapping layer top height', 'm', 'TLTHEIGHT'], '44': ['Mean vertical gradient of refractivity inside trapping layer', 'm-1', 'MEANVGRTL'], '45': ['Minimum vertical gradient of refractivity inside trapping layer', 'm-1', 'MINVGRTL'], '46': ['Net radiation flux', 'W m-2', 'NETRADFLUX'], '47': ['Global irradiance on tilted surfaces', 'W m-2', 'GLIRRTS'], '48': ['Top of persistent contrails', 'm', 'PCONTT'], '49': ['Base of persistent contrails', 'm', 'PCONTB'], '50': ['Convectively-induced turbulence (CIT) (eddy dissipation rate)', 'm2/3 s-1', 'CITEDR'], '51': ['Visibility Through Precipitation', 'm', 'VISPCP'], '52': ['Hail Kinetic Energy Flux', 'J m-2 s-1', 'HAILKEF'], '53-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Maximum Snow Albedo', '%', 'MXSALB'], '193': ['Snow-Free Albedo', '%', 'SNFALB'], '194': ['Slight risk convective outlook', 'categorical', 'SRCONO'], '195': ['Moderate risk convective outlook', 'categorical', 'MRCONO'], '196': ['High risk convective outlook', 'categorical', 'HRCONO'], '197': ['Tornado probability', '%', 'TORPROB'], '198': ['Hail probability', '%', 'HAILPROB'], '199': ['Wind probability', '%', 'WINDPROB'], '200': ['Significant Tornado probability', '%', 'STORPROB'], '201': ['Significant Hail probability', '%', 'SHAILPRO'], '202': ['Significant Wind probability', '%', 'SWINDPRO'], '203': ['Categorical Thunderstorm', 'Code table 4.222', 'TSTMC'], '204': ['Number of mixed layers next to surface', 'integer', 'MIXLY'], '205': ['Flight Category', 'unknown', 'FLGHT'], '206': ['Confidence - Ceiling', 'unknown', 'CICEL'], '207': ['Confidence - Visibility', 'unknown', 'CIVIS'], '208': ['Confidence - Flight Category', 'unknown', 'CIFLT'], '209': ['Low-Level aviation interest', 'unknown', 'LAVNI'], '210': ['High-Level aviation interest', 'unknown', 'HAVNI'], '211': ['Visible, Black Sky Albedo', '%', 'SBSALB'], '212': ['Visible, White Sky Albedo', '%', 'SWSALB'], '213': ['Near IR, Black Sky Albedo', '%', 'NBSALB'], '214': ['Near IR, White Sky Albedo', '%', 'NWSALB'], '215': ['Total Probability of Severe Thunderstorms (Days 2,3)', '%', 'PRSVR'], '216': ['Total Probability of Extreme Severe Thunderstorms (Days 2,3)', '%', 'PRSIGSVR'], '217': ['Supercooled Large Droplet (SLD) Icing', 'See Table 4.207', 'SIPD'], '218': ['Radiative emissivity', 'unknown', 'EPSR'], '219': ['Turbulence Potential Forecast Index', 'unknown', 'TPFI'], '220': ['Categorical Severe Thunderstorm', 'Code table 4.222', 'SVRTS'], '221': ['Probability of Convection', '%', 'PROCON'], '222': ['Convection Potential', 'Code table 4.222', 'CONVP'], '223-231': ['Reserved', 'unknown', 'unknown'], '232': ['Volcanic Ash Forecast Transport and Dispersion', 'log10 (kg m-3)', 'VAFTD'], '233': ['Icing probability', 'non-dim', 'ICPRB'], '234': ['Icing Severity', 'non-dim', 'ICSEV'], '235': ['Joint Fire Weather Probability', '%', 'JFWPRB'], '236': ['Snow Level', 'm', 'SNOWLVL'], '237': ['Dry Thunderstorm Probability', '%', 'DRYTPROB'], '238': ['Ellrod Index', 'unknown', 'ELLINX'], '239': ['Craven-Wiedenfeld Aggregate Severe Parameter', 'Numeric', 'CWASP'], '240': ['Continuous Icing Severity', 'non-dim', 'ICESEVCON'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_20 = {'0': ['Mass Density (Concentration)', 'kg m-3', 'MASSDEN'], '1': ['Column-Integrated Mass Density', 'kg m-2', 'COLMD'], '2': ['Mass Mixing Ratio (Mass Fraction in Air)', 'kg kg-1', 'MASSMR'], '3': ['Atmosphere Emission Mass Flux', 'kg m-2s-1', 'AEMFLX'], '4': ['Atmosphere Net Production Mass Flux', 'kg m-2s-1', 'ANPMFLX'], '5': ['Atmosphere Net Production And Emision Mass Flux', 'kg m-2s-1', 'ANPEMFLX'], '6': ['Surface Dry Deposition Mass Flux', 'kg m-2s-1', 'SDDMFLX'], '7': ['Surface Wet Deposition Mass Flux', 'kg m-2s-1', 'SWDMFLX'], '8': ['Atmosphere Re-Emission Mass Flux', 'kg m-2s-1', 'AREMFLX'], '9': ['Wet Deposition by Large-Scale Precipitation Mass Flux', 'kg m-2s-1', 'WLSMFLX'], '10': ['Wet Deposition by Convective Precipitation Mass Flux', 'kg m-2s-1', 'WDCPMFLX'], '11': ['Sedimentation Mass Flux', 'kg m-2s-1', 'SEDMFLX'], '12': ['Dry Deposition Mass Flux', 'kg m-2s-1', 'DDMFLX'], '13': ['Transfer From Hydrophobic to Hydrophilic', 'kg kg-1s-1', 'TRANHH'], '14': ['Transfer From SO2 (Sulphur Dioxide) to SO4 (Sulphate)', 'kg kg-1s-1', 'TRSDS'], '15': ['Dry deposition velocity', 'm s-1', 'DDVEL'], '16': ['Mass mixing ratio with respect to dry air', 'kg kg-1', 'MSSRDRYA'], '17': ['Mass mixing ratio with respect to wet air', 'kg kg-1', 'MSSRWETA'], '18': ['Potential of hydrogen (pH)', 'pH', 'POTHPH'], '19': ['Loss Rate Due to Reaction with Hydroxyl Radical (OH)', 'kg kg-1 s-1', 'LRATEOH'], '20-49': ['Reserved', 'unknown', 'unknown'], '50': ['Amount in Atmosphere', 'mol', 'AIA'], '51': ['Concentration In Air', 'mol m-3', 'CONAIR'], '52': ['Volume Mixing Ratio (Fraction in Air)', 'mol mol-1', 'VMXR'], '53': ['Chemical Gross Production Rate of Concentration', 'mol m-3s-1', 'CGPRC'], '54': ['Chemical Gross Destruction Rate of Concentration', 'mol m-3s-1', 'CGDRC'], '55': ['Surface Flux', 'mol m-2s-1', 'SFLUX'], '56': ['Changes Of Amount in Atmosphere', 'mol s-1', 'COAIA'], '57': ['Total Yearly Average Burden of The Atmosphere>', 'mol', 'TYABA'], '58': ['Total Yearly Average Atmospheric Loss', 'mol s-1', 'TYAAL'], '59': ['Aerosol Number Concentration', 'm-3', 'ANCON'], '60': ['Aerosol Specific Number Concentration', 'kg-1', 'ASNCON'], '61': ['Maximum of Mass Density', 'kg m-3', 'MXMASSD'], '62': ['Height of Mass Density', 'm', 'HGTMD'], '63': ['Column-Averaged Mass Density in Layer', 'kg m-3', 'CAVEMDL'], '64': ['Mole fraction with respect to dry air', 'mol mol-1', 'MOLRDRYA'], '65': ['Mole fraction with respect to wet air', 'mol mol-1', 'MOLRWETA'], '66': ['Column-integrated in-cloud scavenging rate by precipitation', 'kg m-2 s-1', 'CINCLDSP'], '67': ['Column-integrated below-cloud scavenging rate by precipitation', 'kg m-2 s-1', 'CBLCLDSP'], '68': ['Column-integrated release rate from evaporating precipitation', 'kg m-2 s-1', 'CIRELREP'], '69': ['Column-integrated in-cloud scavenging rate by large-scale precipitation', 'kg m-2 s-1', 'CINCSLSP'], '70': ['Column-integrated below-cloud scavenging rate by large-scale precipitation', 'kg m-2 s-1', 'CBECSLSP'], '71': ['Column-integrated release rate from evaporating large-scale precipitation', 'kg m-2 s-1', 'CRERELSP'], '72': ['Column-integrated in-cloud scavenging rate by convective precipitation', 'kg m-2 s-1', 'CINCSRCP'], '73': ['Column-integrated below-cloud scavenging rate by convective precipitation', 'kg m-2 s-1', 'CBLCSRCP'], '74': ['Column-integrated release rate from evaporating convective precipitation', 'kg m-2 s-1', 'CIRERECP'], '75': ['Wildfire flux', 'kg m-2 s-1', 'WFIREFLX'], '76': ['Emission Rate', 'kg kg-1 s-1', 'EMISFLX'], '77': ['Surface Emission flux', 'kg m-2 s-1', 'SFCEFLX'], '78': ['Column integrated eastward mass flux', 'kg m-2 s-1', 'CEMF'], '79': ['Column integrated northward mass flux', 'kg m-2 s-1', 'CNMF'], '80': ['Column integrated divergence of mass flux', 'kg m-2 s-1', 'CDIVMF'], '81': ['Column integrated net source', 'kg m-2 s-1', 'CNETS'], '82': ['Sink mass flux', 'kg m-2 s-1', 'SNKMFLX'], '83': ['Source mass flux', 'kg m-2 s-1', 'SRCMFLX'], '84': ['Volume-mean total column mixing ratio', 'mol mol-1', 'VTCOLMIXR'], '85-99': ['Reserved', 'unknown', 'unknown'], '100': ['Surface Area Density (Aerosol)', 'm-1', 'SADEN'], '101': ['Vertical Visual Range', 'm', 'ATMTK'], '102': ['Aerosol Optical Thickness', 'Numeric', 'AOTK'], '103': ['Single Scattering Albedo', 'Numeric', 'SSALBK'], '104': ['Asymmetry Factor', 'Numeric', 'ASYSFK'], '105': ['Aerosol Extinction Coefficient', 'm-1', 'AECOEF'], '106': ['Aerosol Absorption Coefficient', 'm-1', 'AACOEF'], '107': ['Aerosol Lidar Backscatter from Satellite', 'm-1sr-1', 'ALBSAT'], '108': ['Aerosol Lidar Backscatter from the Ground', 'm-1sr-1', 'ALBGRD'], '109': ['Aerosol Lidar Extinction from Satellite', 'm-1', 'ALESAT'], '110': ['Aerosol Lidar Extinction from the Ground', 'm-1', 'ALEGRD'], '111': ['Angstrom Exponent', 'Numeric', 'ANGSTEXP'], '112': ['Absorption Aerosol Optical Thickness', 'Numeric', 'SCTAOTK'], '113': ['Aerosol Backscatter Coefficient', 'm-1 sr-1', 'ABCOEF'], '114-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_190 = {'0': ['Arbitrary Text String', 'CCITTIA5', 'ATEXT'], '1-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_191 = {'0': ['Seconds prior to initial reference time (defined in Section 1)', 's', 'TSEC'], '1': ['Geographical Latitude', '° N', 'GEOLAT'], '2': ['Geographical Longitude', '° E', 'GEOLON'], '3': ['Days Since Last Observation', 'd', 'DSLOBS'], '4': ['Tropical cyclone density track', 'Numeric', 'TCDTRACK'], '5': ['Hurricane track in spatiotemporal vicinity', 'boolean', 'HURTSV'], '6': ['Tropical storm track in spatiotemporal vicinity', 'boolean', 'TSTSV'], '7': ['Tropical depression track in spatiotemporal vicinity', 'boolean', 'TDTSV'], '8-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Latitude (-90 to 90)', '°', 'NLAT'], '193': ['East Longitude (0 to 360)', '°', 'ELON'], '194': ['Seconds prior to initial reference time', 's', 'RTSEC'], '195': ['Model Layer number (From bottom up)', 'unknown', 'MLYNO'], '196': ['Latitude (nearest neighbor) (-90 to 90)', '°', 'NLATN'], '197': ['East Longitude (nearest neighbor) (0 to 360)', '°', 'ELONN'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_192 = {'1': ['Covariance between zonal and meridional components of the wind. Defined as [uv]-[u][v], where "[]" indicates the mean over the indicated time span.', 'm2/s2', 'COVMZ'], '2': ['Covariance between zonal component of the wind and temperature. Defined as [uT]-[u][T], where "[]" indicates the mean over the indicated time span.', 'K*m/s', 'COVTZ'], '3': ['Covariance between meridional component of the wind and temperature. Defined as [vT]-[v][T], where "[]" indicates the mean over the indicated time span.', 'K*m/s', 'COVTM'], '4': ['Covariance between temperature and vertical component of the wind. Defined as [wT]-[w][T], where "[]" indicates the mean over the indicated time span.', 'K*m/s', 'COVTW'], '5': ['Covariance between zonal and zonal components of the wind. Defined as [uu]-[u][u], where "[]" indicates the mean over the indicated time span.', 'm2/s2', 'COVZZ'], '6': ['Covariance between meridional and meridional components of the wind. Defined as [vv]-[v][v], where "[]" indicates the mean over the indicated time span.', 'm2/s2', 'COVMM'], '7': ['Covariance between specific humidity and zonal components of the wind. Defined as [uq]-[u][q], where "[]" indicates the mean over the indicated time span.', 'kg/kg*m/s', 'COVQZ'], '8': ['Covariance between specific humidity and meridional components of the wind. Defined as [vq]-[v][q], where "[]" indicates the mean over the indicated time span.', 'kg/kg*m/s', 'COVQM'], '9': ['Covariance between temperature and vertical components of the wind. Defined as [ΩT]-[Ω][T], where "[]" indicates the mean over the indicated time span.', 'K*Pa/s', 'COVTVV'], '10': ['Covariance between specific humidity and vertical components of the wind. Defined as [Ωq]-[Ω][q], where "[]" indicates the mean over the indicated time span.', 'kg/kg*Pa/s', 'COVQVV'], '11': ['Covariance between surface pressure and surface pressure. Defined as [Psfc]-[Psfc][Psfc], where "[]" indicates the mean over the indicated time span.', 'Pa*Pa', 'COVPSPS'], '12': ['Covariance between specific humidity and specific humidy. Defined as [qq]-[q][q], where "[]" indicates the mean over the indicated time span.', 'kg/kg*kg/kg', 'COVQQ'], '13': ['Covariance between vertical and vertical components of the wind. Defined as [ΩΩ]-[Ω][Ω], where "[]" indicates the mean over the indicated time span.', 'Pa2/s2', 'COVVVVV'], '14': ['Covariance between temperature and temperature. Defined as [TT]-[T][T], where "[]" indicates the mean over the indicated time span.', 'K*K', 'COVTT'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_0_0_ndfd = {'193': ['Apparent Temperature', 'K', 'APPT']}
table_4_2_0_1_ndfd = {'192': ['Weather Information', 'WxInfo', 'WX']}
table_4_2_0_19_ndfd = {'194': ['Convective Hazard Outlook', 'categorical', 'CONVOUTLOOK'], '197': ['Probability of Tornado', '%', 'PTORNADO'], '198': ['Probability of Hail', '%', 'PHAIL'], '199': ['Probability of Damaging Wind', '%', 'PWIND'], '200': ['Probability of Extreme Tornado', '%', 'PXTRMTORN'], '201': ['Probability of Extreme Hail', '%', 'PXTRMHAIL'], '202': ['Probability of Extreme Wind', '%', 'PXTRMWIND'], '215': ['Total Probability of Severe Thunderstorms', '%', 'TOTALSVRPROB'], '216': ['Total Probability of Extreme Severe Thunderstorms', '%', 'TOTALXTRMPROB'], '217': ['Watch Warning Advisory', 'WxInfo', 'WWA']}
table_4_2_0_192_ndfd = {'192': ['Critical Fire Weather', '', 'FIREWX'], '194': ['Dry Lightning', '', 'DRYLIGHTNING']}